# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MaintenanceRunSummary(object):
    """
    Details of a maintenance run.
    """

    #: A constant which can be used with the lifecycle_state property of a MaintenanceRunSummary.
    #: This constant has a value of "SCHEDULED"
    LIFECYCLE_STATE_SCHEDULED = "SCHEDULED"

    #: A constant which can be used with the lifecycle_state property of a MaintenanceRunSummary.
    #: This constant has a value of "IN_PROGRESS"
    LIFECYCLE_STATE_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the lifecycle_state property of a MaintenanceRunSummary.
    #: This constant has a value of "SUCCEEDED"
    LIFECYCLE_STATE_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the lifecycle_state property of a MaintenanceRunSummary.
    #: This constant has a value of "SKIPPED"
    LIFECYCLE_STATE_SKIPPED = "SKIPPED"

    #: A constant which can be used with the lifecycle_state property of a MaintenanceRunSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a MaintenanceRunSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a MaintenanceRunSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a MaintenanceRunSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a MaintenanceRunSummary.
    #: This constant has a value of "CANCELED"
    LIFECYCLE_STATE_CANCELED = "CANCELED"

    #: A constant which can be used with the target_resource_type property of a MaintenanceRunSummary.
    #: This constant has a value of "AUTONOMOUS_EXADATA_INFRASTRUCTURE"
    TARGET_RESOURCE_TYPE_AUTONOMOUS_EXADATA_INFRASTRUCTURE = "AUTONOMOUS_EXADATA_INFRASTRUCTURE"

    #: A constant which can be used with the target_resource_type property of a MaintenanceRunSummary.
    #: This constant has a value of "AUTONOMOUS_CONTAINER_DATABASE"
    TARGET_RESOURCE_TYPE_AUTONOMOUS_CONTAINER_DATABASE = "AUTONOMOUS_CONTAINER_DATABASE"

    #: A constant which can be used with the target_resource_type property of a MaintenanceRunSummary.
    #: This constant has a value of "EXADATA_DB_SYSTEM"
    TARGET_RESOURCE_TYPE_EXADATA_DB_SYSTEM = "EXADATA_DB_SYSTEM"

    #: A constant which can be used with the target_resource_type property of a MaintenanceRunSummary.
    #: This constant has a value of "CLOUD_EXADATA_INFRASTRUCTURE"
    TARGET_RESOURCE_TYPE_CLOUD_EXADATA_INFRASTRUCTURE = "CLOUD_EXADATA_INFRASTRUCTURE"

    #: A constant which can be used with the target_resource_type property of a MaintenanceRunSummary.
    #: This constant has a value of "EXACC_INFRASTRUCTURE"
    TARGET_RESOURCE_TYPE_EXACC_INFRASTRUCTURE = "EXACC_INFRASTRUCTURE"

    #: A constant which can be used with the target_resource_type property of a MaintenanceRunSummary.
    #: This constant has a value of "AUTONOMOUS_VM_CLUSTER"
    TARGET_RESOURCE_TYPE_AUTONOMOUS_VM_CLUSTER = "AUTONOMOUS_VM_CLUSTER"

    #: A constant which can be used with the target_resource_type property of a MaintenanceRunSummary.
    #: This constant has a value of "AUTONOMOUS_DATABASE"
    TARGET_RESOURCE_TYPE_AUTONOMOUS_DATABASE = "AUTONOMOUS_DATABASE"

    #: A constant which can be used with the maintenance_type property of a MaintenanceRunSummary.
    #: This constant has a value of "PLANNED"
    MAINTENANCE_TYPE_PLANNED = "PLANNED"

    #: A constant which can be used with the maintenance_type property of a MaintenanceRunSummary.
    #: This constant has a value of "UNPLANNED"
    MAINTENANCE_TYPE_UNPLANNED = "UNPLANNED"

    #: A constant which can be used with the maintenance_subtype property of a MaintenanceRunSummary.
    #: This constant has a value of "QUARTERLY"
    MAINTENANCE_SUBTYPE_QUARTERLY = "QUARTERLY"

    #: A constant which can be used with the maintenance_subtype property of a MaintenanceRunSummary.
    #: This constant has a value of "HARDWARE"
    MAINTENANCE_SUBTYPE_HARDWARE = "HARDWARE"

    #: A constant which can be used with the maintenance_subtype property of a MaintenanceRunSummary.
    #: This constant has a value of "CRITICAL"
    MAINTENANCE_SUBTYPE_CRITICAL = "CRITICAL"

    #: A constant which can be used with the maintenance_subtype property of a MaintenanceRunSummary.
    #: This constant has a value of "INFRASTRUCTURE"
    MAINTENANCE_SUBTYPE_INFRASTRUCTURE = "INFRASTRUCTURE"

    #: A constant which can be used with the maintenance_subtype property of a MaintenanceRunSummary.
    #: This constant has a value of "DATABASE"
    MAINTENANCE_SUBTYPE_DATABASE = "DATABASE"

    #: A constant which can be used with the maintenance_subtype property of a MaintenanceRunSummary.
    #: This constant has a value of "ONEOFF"
    MAINTENANCE_SUBTYPE_ONEOFF = "ONEOFF"

    #: A constant which can be used with the patching_mode property of a MaintenanceRunSummary.
    #: This constant has a value of "ROLLING"
    PATCHING_MODE_ROLLING = "ROLLING"

    #: A constant which can be used with the patching_mode property of a MaintenanceRunSummary.
    #: This constant has a value of "NONROLLING"
    PATCHING_MODE_NONROLLING = "NONROLLING"

    #: A constant which can be used with the patching_status property of a MaintenanceRunSummary.
    #: This constant has a value of "PATCHING"
    PATCHING_STATUS_PATCHING = "PATCHING"

    #: A constant which can be used with the patching_status property of a MaintenanceRunSummary.
    #: This constant has a value of "WAITING"
    PATCHING_STATUS_WAITING = "WAITING"

    #: A constant which can be used with the patching_status property of a MaintenanceRunSummary.
    #: This constant has a value of "SCHEDULED"
    PATCHING_STATUS_SCHEDULED = "SCHEDULED"

    def __init__(self, **kwargs):
        """
        Initializes a new MaintenanceRunSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this MaintenanceRunSummary.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this MaintenanceRunSummary.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this MaintenanceRunSummary.
        :type display_name: str

        :param description:
            The value to assign to the description property of this MaintenanceRunSummary.
        :type description: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this MaintenanceRunSummary.
            Allowed values for this property are: "SCHEDULED", "IN_PROGRESS", "SUCCEEDED", "SKIPPED", "FAILED", "UPDATING", "DELETING", "DELETED", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this MaintenanceRunSummary.
        :type lifecycle_details: str

        :param time_scheduled:
            The value to assign to the time_scheduled property of this MaintenanceRunSummary.
        :type time_scheduled: datetime

        :param time_started:
            The value to assign to the time_started property of this MaintenanceRunSummary.
        :type time_started: datetime

        :param time_ended:
            The value to assign to the time_ended property of this MaintenanceRunSummary.
        :type time_ended: datetime

        :param target_resource_type:
            The value to assign to the target_resource_type property of this MaintenanceRunSummary.
            Allowed values for this property are: "AUTONOMOUS_EXADATA_INFRASTRUCTURE", "AUTONOMOUS_CONTAINER_DATABASE", "EXADATA_DB_SYSTEM", "CLOUD_EXADATA_INFRASTRUCTURE", "EXACC_INFRASTRUCTURE", "AUTONOMOUS_VM_CLUSTER", "AUTONOMOUS_DATABASE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type target_resource_type: str

        :param target_resource_id:
            The value to assign to the target_resource_id property of this MaintenanceRunSummary.
        :type target_resource_id: str

        :param maintenance_type:
            The value to assign to the maintenance_type property of this MaintenanceRunSummary.
            Allowed values for this property are: "PLANNED", "UNPLANNED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type maintenance_type: str

        :param patch_id:
            The value to assign to the patch_id property of this MaintenanceRunSummary.
        :type patch_id: str

        :param maintenance_subtype:
            The value to assign to the maintenance_subtype property of this MaintenanceRunSummary.
            Allowed values for this property are: "QUARTERLY", "HARDWARE", "CRITICAL", "INFRASTRUCTURE", "DATABASE", "ONEOFF", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type maintenance_subtype: str

        :param peer_maintenance_run_id:
            The value to assign to the peer_maintenance_run_id property of this MaintenanceRunSummary.
        :type peer_maintenance_run_id: str

        :param patching_mode:
            The value to assign to the patching_mode property of this MaintenanceRunSummary.
            Allowed values for this property are: "ROLLING", "NONROLLING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type patching_mode: str

        :param patch_failure_count:
            The value to assign to the patch_failure_count property of this MaintenanceRunSummary.
        :type patch_failure_count: int

        :param target_db_server_version:
            The value to assign to the target_db_server_version property of this MaintenanceRunSummary.
        :type target_db_server_version: str

        :param target_storage_server_version:
            The value to assign to the target_storage_server_version property of this MaintenanceRunSummary.
        :type target_storage_server_version: str

        :param is_custom_action_timeout_enabled:
            The value to assign to the is_custom_action_timeout_enabled property of this MaintenanceRunSummary.
        :type is_custom_action_timeout_enabled: bool

        :param custom_action_timeout_in_mins:
            The value to assign to the custom_action_timeout_in_mins property of this MaintenanceRunSummary.
        :type custom_action_timeout_in_mins: int

        :param current_custom_action_timeout_in_mins:
            The value to assign to the current_custom_action_timeout_in_mins property of this MaintenanceRunSummary.
        :type current_custom_action_timeout_in_mins: int

        :param patching_status:
            The value to assign to the patching_status property of this MaintenanceRunSummary.
            Allowed values for this property are: "PATCHING", "WAITING", "SCHEDULED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type patching_status: str

        :param patching_start_time:
            The value to assign to the patching_start_time property of this MaintenanceRunSummary.
        :type patching_start_time: datetime

        :param patching_end_time:
            The value to assign to the patching_end_time property of this MaintenanceRunSummary.
        :type patching_end_time: datetime

        :param estimated_patching_time:
            The value to assign to the estimated_patching_time property of this MaintenanceRunSummary.
        :type estimated_patching_time: oci.database.models.EstimatedPatchingTime

        :param current_patching_component:
            The value to assign to the current_patching_component property of this MaintenanceRunSummary.
        :type current_patching_component: str

        :param estimated_component_patching_start_time:
            The value to assign to the estimated_component_patching_start_time property of this MaintenanceRunSummary.
        :type estimated_component_patching_start_time: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'description': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'time_scheduled': 'datetime',
            'time_started': 'datetime',
            'time_ended': 'datetime',
            'target_resource_type': 'str',
            'target_resource_id': 'str',
            'maintenance_type': 'str',
            'patch_id': 'str',
            'maintenance_subtype': 'str',
            'peer_maintenance_run_id': 'str',
            'patching_mode': 'str',
            'patch_failure_count': 'int',
            'target_db_server_version': 'str',
            'target_storage_server_version': 'str',
            'is_custom_action_timeout_enabled': 'bool',
            'custom_action_timeout_in_mins': 'int',
            'current_custom_action_timeout_in_mins': 'int',
            'patching_status': 'str',
            'patching_start_time': 'datetime',
            'patching_end_time': 'datetime',
            'estimated_patching_time': 'EstimatedPatchingTime',
            'current_patching_component': 'str',
            'estimated_component_patching_start_time': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'description': 'description',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'time_scheduled': 'timeScheduled',
            'time_started': 'timeStarted',
            'time_ended': 'timeEnded',
            'target_resource_type': 'targetResourceType',
            'target_resource_id': 'targetResourceId',
            'maintenance_type': 'maintenanceType',
            'patch_id': 'patchId',
            'maintenance_subtype': 'maintenanceSubtype',
            'peer_maintenance_run_id': 'peerMaintenanceRunId',
            'patching_mode': 'patchingMode',
            'patch_failure_count': 'patchFailureCount',
            'target_db_server_version': 'targetDbServerVersion',
            'target_storage_server_version': 'targetStorageServerVersion',
            'is_custom_action_timeout_enabled': 'isCustomActionTimeoutEnabled',
            'custom_action_timeout_in_mins': 'customActionTimeoutInMins',
            'current_custom_action_timeout_in_mins': 'currentCustomActionTimeoutInMins',
            'patching_status': 'patchingStatus',
            'patching_start_time': 'patchingStartTime',
            'patching_end_time': 'patchingEndTime',
            'estimated_patching_time': 'estimatedPatchingTime',
            'current_patching_component': 'currentPatchingComponent',
            'estimated_component_patching_start_time': 'estimatedComponentPatchingStartTime'
        }

        self._id = None
        self._compartment_id = None
        self._display_name = None
        self._description = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._time_scheduled = None
        self._time_started = None
        self._time_ended = None
        self._target_resource_type = None
        self._target_resource_id = None
        self._maintenance_type = None
        self._patch_id = None
        self._maintenance_subtype = None
        self._peer_maintenance_run_id = None
        self._patching_mode = None
        self._patch_failure_count = None
        self._target_db_server_version = None
        self._target_storage_server_version = None
        self._is_custom_action_timeout_enabled = None
        self._custom_action_timeout_in_mins = None
        self._current_custom_action_timeout_in_mins = None
        self._patching_status = None
        self._patching_start_time = None
        self._patching_end_time = None
        self._estimated_patching_time = None
        self._current_patching_component = None
        self._estimated_component_patching_start_time = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this MaintenanceRunSummary.
        The OCID of the maintenance run.


        :return: The id of this MaintenanceRunSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this MaintenanceRunSummary.
        The OCID of the maintenance run.


        :param id: The id of this MaintenanceRunSummary.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this MaintenanceRunSummary.
        The OCID of the compartment.


        :return: The compartment_id of this MaintenanceRunSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this MaintenanceRunSummary.
        The OCID of the compartment.


        :param compartment_id: The compartment_id of this MaintenanceRunSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this MaintenanceRunSummary.
        The user-friendly name for the maintenance run.


        :return: The display_name of this MaintenanceRunSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this MaintenanceRunSummary.
        The user-friendly name for the maintenance run.


        :param display_name: The display_name of this MaintenanceRunSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this MaintenanceRunSummary.
        Description of the maintenance run.


        :return: The description of this MaintenanceRunSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this MaintenanceRunSummary.
        Description of the maintenance run.


        :param description: The description of this MaintenanceRunSummary.
        :type: str
        """
        self._description = description

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this MaintenanceRunSummary.
        The current state of the maintenance run. For Autonomous Database on shared Exadata infrastructure, valid states are IN_PROGRESS, SUCCEEDED and FAILED.

        Allowed values for this property are: "SCHEDULED", "IN_PROGRESS", "SUCCEEDED", "SKIPPED", "FAILED", "UPDATING", "DELETING", "DELETED", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this MaintenanceRunSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this MaintenanceRunSummary.
        The current state of the maintenance run. For Autonomous Database on shared Exadata infrastructure, valid states are IN_PROGRESS, SUCCEEDED and FAILED.


        :param lifecycle_state: The lifecycle_state of this MaintenanceRunSummary.
        :type: str
        """
        allowed_values = ["SCHEDULED", "IN_PROGRESS", "SUCCEEDED", "SKIPPED", "FAILED", "UPDATING", "DELETING", "DELETED", "CANCELED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this MaintenanceRunSummary.
        Additional information about the current lifecycle state.


        :return: The lifecycle_details of this MaintenanceRunSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this MaintenanceRunSummary.
        Additional information about the current lifecycle state.


        :param lifecycle_details: The lifecycle_details of this MaintenanceRunSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def time_scheduled(self):
        """
        **[Required]** Gets the time_scheduled of this MaintenanceRunSummary.
        The date and time the maintenance run is scheduled to occur.


        :return: The time_scheduled of this MaintenanceRunSummary.
        :rtype: datetime
        """
        return self._time_scheduled

    @time_scheduled.setter
    def time_scheduled(self, time_scheduled):
        """
        Sets the time_scheduled of this MaintenanceRunSummary.
        The date and time the maintenance run is scheduled to occur.


        :param time_scheduled: The time_scheduled of this MaintenanceRunSummary.
        :type: datetime
        """
        self._time_scheduled = time_scheduled

    @property
    def time_started(self):
        """
        Gets the time_started of this MaintenanceRunSummary.
        The date and time the maintenance run starts.


        :return: The time_started of this MaintenanceRunSummary.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this MaintenanceRunSummary.
        The date and time the maintenance run starts.


        :param time_started: The time_started of this MaintenanceRunSummary.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_ended(self):
        """
        Gets the time_ended of this MaintenanceRunSummary.
        The date and time the maintenance run was completed.


        :return: The time_ended of this MaintenanceRunSummary.
        :rtype: datetime
        """
        return self._time_ended

    @time_ended.setter
    def time_ended(self, time_ended):
        """
        Sets the time_ended of this MaintenanceRunSummary.
        The date and time the maintenance run was completed.


        :param time_ended: The time_ended of this MaintenanceRunSummary.
        :type: datetime
        """
        self._time_ended = time_ended

    @property
    def target_resource_type(self):
        """
        Gets the target_resource_type of this MaintenanceRunSummary.
        The type of the target resource on which the maintenance run occurs.

        Allowed values for this property are: "AUTONOMOUS_EXADATA_INFRASTRUCTURE", "AUTONOMOUS_CONTAINER_DATABASE", "EXADATA_DB_SYSTEM", "CLOUD_EXADATA_INFRASTRUCTURE", "EXACC_INFRASTRUCTURE", "AUTONOMOUS_VM_CLUSTER", "AUTONOMOUS_DATABASE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The target_resource_type of this MaintenanceRunSummary.
        :rtype: str
        """
        return self._target_resource_type

    @target_resource_type.setter
    def target_resource_type(self, target_resource_type):
        """
        Sets the target_resource_type of this MaintenanceRunSummary.
        The type of the target resource on which the maintenance run occurs.


        :param target_resource_type: The target_resource_type of this MaintenanceRunSummary.
        :type: str
        """
        allowed_values = ["AUTONOMOUS_EXADATA_INFRASTRUCTURE", "AUTONOMOUS_CONTAINER_DATABASE", "EXADATA_DB_SYSTEM", "CLOUD_EXADATA_INFRASTRUCTURE", "EXACC_INFRASTRUCTURE", "AUTONOMOUS_VM_CLUSTER", "AUTONOMOUS_DATABASE"]
        if not value_allowed_none_or_none_sentinel(target_resource_type, allowed_values):
            target_resource_type = 'UNKNOWN_ENUM_VALUE'
        self._target_resource_type = target_resource_type

    @property
    def target_resource_id(self):
        """
        Gets the target_resource_id of this MaintenanceRunSummary.
        The ID of the target resource on which the maintenance run occurs.


        :return: The target_resource_id of this MaintenanceRunSummary.
        :rtype: str
        """
        return self._target_resource_id

    @target_resource_id.setter
    def target_resource_id(self, target_resource_id):
        """
        Sets the target_resource_id of this MaintenanceRunSummary.
        The ID of the target resource on which the maintenance run occurs.


        :param target_resource_id: The target_resource_id of this MaintenanceRunSummary.
        :type: str
        """
        self._target_resource_id = target_resource_id

    @property
    def maintenance_type(self):
        """
        Gets the maintenance_type of this MaintenanceRunSummary.
        Maintenance type.

        Allowed values for this property are: "PLANNED", "UNPLANNED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The maintenance_type of this MaintenanceRunSummary.
        :rtype: str
        """
        return self._maintenance_type

    @maintenance_type.setter
    def maintenance_type(self, maintenance_type):
        """
        Sets the maintenance_type of this MaintenanceRunSummary.
        Maintenance type.


        :param maintenance_type: The maintenance_type of this MaintenanceRunSummary.
        :type: str
        """
        allowed_values = ["PLANNED", "UNPLANNED"]
        if not value_allowed_none_or_none_sentinel(maintenance_type, allowed_values):
            maintenance_type = 'UNKNOWN_ENUM_VALUE'
        self._maintenance_type = maintenance_type

    @property
    def patch_id(self):
        """
        Gets the patch_id of this MaintenanceRunSummary.
        The unique identifier of the patch. The identifier string includes the patch type, the Oracle Database version, and the patch creation date (using the format YYMMDD). For example, the identifier `ru_patch_19.9.0.0_201030` is used for an RU patch for Oracle Database 19.9.0.0 that was released October 30, 2020.


        :return: The patch_id of this MaintenanceRunSummary.
        :rtype: str
        """
        return self._patch_id

    @patch_id.setter
    def patch_id(self, patch_id):
        """
        Sets the patch_id of this MaintenanceRunSummary.
        The unique identifier of the patch. The identifier string includes the patch type, the Oracle Database version, and the patch creation date (using the format YYMMDD). For example, the identifier `ru_patch_19.9.0.0_201030` is used for an RU patch for Oracle Database 19.9.0.0 that was released October 30, 2020.


        :param patch_id: The patch_id of this MaintenanceRunSummary.
        :type: str
        """
        self._patch_id = patch_id

    @property
    def maintenance_subtype(self):
        """
        Gets the maintenance_subtype of this MaintenanceRunSummary.
        Maintenance sub-type.

        Allowed values for this property are: "QUARTERLY", "HARDWARE", "CRITICAL", "INFRASTRUCTURE", "DATABASE", "ONEOFF", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The maintenance_subtype of this MaintenanceRunSummary.
        :rtype: str
        """
        return self._maintenance_subtype

    @maintenance_subtype.setter
    def maintenance_subtype(self, maintenance_subtype):
        """
        Sets the maintenance_subtype of this MaintenanceRunSummary.
        Maintenance sub-type.


        :param maintenance_subtype: The maintenance_subtype of this MaintenanceRunSummary.
        :type: str
        """
        allowed_values = ["QUARTERLY", "HARDWARE", "CRITICAL", "INFRASTRUCTURE", "DATABASE", "ONEOFF"]
        if not value_allowed_none_or_none_sentinel(maintenance_subtype, allowed_values):
            maintenance_subtype = 'UNKNOWN_ENUM_VALUE'
        self._maintenance_subtype = maintenance_subtype

    @property
    def peer_maintenance_run_id(self):
        """
        Gets the peer_maintenance_run_id of this MaintenanceRunSummary.
        The `OCID`__ of the maintenance run for the Autonomous Data Guard association's peer container database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The peer_maintenance_run_id of this MaintenanceRunSummary.
        :rtype: str
        """
        return self._peer_maintenance_run_id

    @peer_maintenance_run_id.setter
    def peer_maintenance_run_id(self, peer_maintenance_run_id):
        """
        Sets the peer_maintenance_run_id of this MaintenanceRunSummary.
        The `OCID`__ of the maintenance run for the Autonomous Data Guard association's peer container database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param peer_maintenance_run_id: The peer_maintenance_run_id of this MaintenanceRunSummary.
        :type: str
        """
        self._peer_maintenance_run_id = peer_maintenance_run_id

    @property
    def patching_mode(self):
        """
        Gets the patching_mode of this MaintenanceRunSummary.
        Cloud Exadata infrastructure node patching method, either \"ROLLING\" or \"NONROLLING\". Default value is ROLLING.

        *IMPORTANT*: Non-rolling infrastructure patching involves system down time. See `Oracle-Managed Infrastructure Maintenance Updates`__ for more information.

        __ https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/examaintenance.htm#Oracle

        Allowed values for this property are: "ROLLING", "NONROLLING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The patching_mode of this MaintenanceRunSummary.
        :rtype: str
        """
        return self._patching_mode

    @patching_mode.setter
    def patching_mode(self, patching_mode):
        """
        Sets the patching_mode of this MaintenanceRunSummary.
        Cloud Exadata infrastructure node patching method, either \"ROLLING\" or \"NONROLLING\". Default value is ROLLING.

        *IMPORTANT*: Non-rolling infrastructure patching involves system down time. See `Oracle-Managed Infrastructure Maintenance Updates`__ for more information.

        __ https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/examaintenance.htm#Oracle


        :param patching_mode: The patching_mode of this MaintenanceRunSummary.
        :type: str
        """
        allowed_values = ["ROLLING", "NONROLLING"]
        if not value_allowed_none_or_none_sentinel(patching_mode, allowed_values):
            patching_mode = 'UNKNOWN_ENUM_VALUE'
        self._patching_mode = patching_mode

    @property
    def patch_failure_count(self):
        """
        Gets the patch_failure_count of this MaintenanceRunSummary.
        Contain the patch failure count.


        :return: The patch_failure_count of this MaintenanceRunSummary.
        :rtype: int
        """
        return self._patch_failure_count

    @patch_failure_count.setter
    def patch_failure_count(self, patch_failure_count):
        """
        Sets the patch_failure_count of this MaintenanceRunSummary.
        Contain the patch failure count.


        :param patch_failure_count: The patch_failure_count of this MaintenanceRunSummary.
        :type: int
        """
        self._patch_failure_count = patch_failure_count

    @property
    def target_db_server_version(self):
        """
        Gets the target_db_server_version of this MaintenanceRunSummary.
        The target software version for the database server patching operation.


        :return: The target_db_server_version of this MaintenanceRunSummary.
        :rtype: str
        """
        return self._target_db_server_version

    @target_db_server_version.setter
    def target_db_server_version(self, target_db_server_version):
        """
        Sets the target_db_server_version of this MaintenanceRunSummary.
        The target software version for the database server patching operation.


        :param target_db_server_version: The target_db_server_version of this MaintenanceRunSummary.
        :type: str
        """
        self._target_db_server_version = target_db_server_version

    @property
    def target_storage_server_version(self):
        """
        Gets the target_storage_server_version of this MaintenanceRunSummary.
        The target Cell version that is to be patched to.


        :return: The target_storage_server_version of this MaintenanceRunSummary.
        :rtype: str
        """
        return self._target_storage_server_version

    @target_storage_server_version.setter
    def target_storage_server_version(self, target_storage_server_version):
        """
        Sets the target_storage_server_version of this MaintenanceRunSummary.
        The target Cell version that is to be patched to.


        :param target_storage_server_version: The target_storage_server_version of this MaintenanceRunSummary.
        :type: str
        """
        self._target_storage_server_version = target_storage_server_version

    @property
    def is_custom_action_timeout_enabled(self):
        """
        Gets the is_custom_action_timeout_enabled of this MaintenanceRunSummary.
        If true, enables the configuration of a custom action timeout (waiting period) between database servers patching operations.


        :return: The is_custom_action_timeout_enabled of this MaintenanceRunSummary.
        :rtype: bool
        """
        return self._is_custom_action_timeout_enabled

    @is_custom_action_timeout_enabled.setter
    def is_custom_action_timeout_enabled(self, is_custom_action_timeout_enabled):
        """
        Sets the is_custom_action_timeout_enabled of this MaintenanceRunSummary.
        If true, enables the configuration of a custom action timeout (waiting period) between database servers patching operations.


        :param is_custom_action_timeout_enabled: The is_custom_action_timeout_enabled of this MaintenanceRunSummary.
        :type: bool
        """
        self._is_custom_action_timeout_enabled = is_custom_action_timeout_enabled

    @property
    def custom_action_timeout_in_mins(self):
        """
        Gets the custom_action_timeout_in_mins of this MaintenanceRunSummary.
        Determines the amount of time the system will wait before the start of each database server patching operation.
        Specify a number of minutes, from 15 to 120.


        :return: The custom_action_timeout_in_mins of this MaintenanceRunSummary.
        :rtype: int
        """
        return self._custom_action_timeout_in_mins

    @custom_action_timeout_in_mins.setter
    def custom_action_timeout_in_mins(self, custom_action_timeout_in_mins):
        """
        Sets the custom_action_timeout_in_mins of this MaintenanceRunSummary.
        Determines the amount of time the system will wait before the start of each database server patching operation.
        Specify a number of minutes, from 15 to 120.


        :param custom_action_timeout_in_mins: The custom_action_timeout_in_mins of this MaintenanceRunSummary.
        :type: int
        """
        self._custom_action_timeout_in_mins = custom_action_timeout_in_mins

    @property
    def current_custom_action_timeout_in_mins(self):
        """
        Gets the current_custom_action_timeout_in_mins of this MaintenanceRunSummary.
        Extend current custom action timeout between the current database servers during waiting state, from 0 (zero) to 30 minutes.


        :return: The current_custom_action_timeout_in_mins of this MaintenanceRunSummary.
        :rtype: int
        """
        return self._current_custom_action_timeout_in_mins

    @current_custom_action_timeout_in_mins.setter
    def current_custom_action_timeout_in_mins(self, current_custom_action_timeout_in_mins):
        """
        Sets the current_custom_action_timeout_in_mins of this MaintenanceRunSummary.
        Extend current custom action timeout between the current database servers during waiting state, from 0 (zero) to 30 minutes.


        :param current_custom_action_timeout_in_mins: The current_custom_action_timeout_in_mins of this MaintenanceRunSummary.
        :type: int
        """
        self._current_custom_action_timeout_in_mins = current_custom_action_timeout_in_mins

    @property
    def patching_status(self):
        """
        Gets the patching_status of this MaintenanceRunSummary.
        The status of the patching operation.

        Allowed values for this property are: "PATCHING", "WAITING", "SCHEDULED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The patching_status of this MaintenanceRunSummary.
        :rtype: str
        """
        return self._patching_status

    @patching_status.setter
    def patching_status(self, patching_status):
        """
        Sets the patching_status of this MaintenanceRunSummary.
        The status of the patching operation.


        :param patching_status: The patching_status of this MaintenanceRunSummary.
        :type: str
        """
        allowed_values = ["PATCHING", "WAITING", "SCHEDULED"]
        if not value_allowed_none_or_none_sentinel(patching_status, allowed_values):
            patching_status = 'UNKNOWN_ENUM_VALUE'
        self._patching_status = patching_status

    @property
    def patching_start_time(self):
        """
        Gets the patching_start_time of this MaintenanceRunSummary.
        The time when the patching operation started.


        :return: The patching_start_time of this MaintenanceRunSummary.
        :rtype: datetime
        """
        return self._patching_start_time

    @patching_start_time.setter
    def patching_start_time(self, patching_start_time):
        """
        Sets the patching_start_time of this MaintenanceRunSummary.
        The time when the patching operation started.


        :param patching_start_time: The patching_start_time of this MaintenanceRunSummary.
        :type: datetime
        """
        self._patching_start_time = patching_start_time

    @property
    def patching_end_time(self):
        """
        Gets the patching_end_time of this MaintenanceRunSummary.
        The time when the patching operation ended.


        :return: The patching_end_time of this MaintenanceRunSummary.
        :rtype: datetime
        """
        return self._patching_end_time

    @patching_end_time.setter
    def patching_end_time(self, patching_end_time):
        """
        Sets the patching_end_time of this MaintenanceRunSummary.
        The time when the patching operation ended.


        :param patching_end_time: The patching_end_time of this MaintenanceRunSummary.
        :type: datetime
        """
        self._patching_end_time = patching_end_time

    @property
    def estimated_patching_time(self):
        """
        Gets the estimated_patching_time of this MaintenanceRunSummary.

        :return: The estimated_patching_time of this MaintenanceRunSummary.
        :rtype: oci.database.models.EstimatedPatchingTime
        """
        return self._estimated_patching_time

    @estimated_patching_time.setter
    def estimated_patching_time(self, estimated_patching_time):
        """
        Sets the estimated_patching_time of this MaintenanceRunSummary.

        :param estimated_patching_time: The estimated_patching_time of this MaintenanceRunSummary.
        :type: oci.database.models.EstimatedPatchingTime
        """
        self._estimated_patching_time = estimated_patching_time

    @property
    def current_patching_component(self):
        """
        Gets the current_patching_component of this MaintenanceRunSummary.
        The name of the current infrastruture component that is getting patched.


        :return: The current_patching_component of this MaintenanceRunSummary.
        :rtype: str
        """
        return self._current_patching_component

    @current_patching_component.setter
    def current_patching_component(self, current_patching_component):
        """
        Sets the current_patching_component of this MaintenanceRunSummary.
        The name of the current infrastruture component that is getting patched.


        :param current_patching_component: The current_patching_component of this MaintenanceRunSummary.
        :type: str
        """
        self._current_patching_component = current_patching_component

    @property
    def estimated_component_patching_start_time(self):
        """
        Gets the estimated_component_patching_start_time of this MaintenanceRunSummary.
        The estimated start time of the next infrastruture component patching operation.


        :return: The estimated_component_patching_start_time of this MaintenanceRunSummary.
        :rtype: datetime
        """
        return self._estimated_component_patching_start_time

    @estimated_component_patching_start_time.setter
    def estimated_component_patching_start_time(self, estimated_component_patching_start_time):
        """
        Sets the estimated_component_patching_start_time of this MaintenanceRunSummary.
        The estimated start time of the next infrastruture component patching operation.


        :param estimated_component_patching_start_time: The estimated_component_patching_start_time of this MaintenanceRunSummary.
        :type: datetime
        """
        self._estimated_component_patching_start_time = estimated_component_patching_start_time

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .input_location import InputLocation
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ObjectListInlineInputLocation(InputLocation):
    """
    A list of object locations in Object Storage inline in request.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ObjectListInlineInputLocation object with values from keyword arguments. The default value of the :py:attr:`~oci.ai_speech.models.ObjectListInlineInputLocation.location_type` attribute
        of this class is ``OBJECT_LIST_INLINE_INPUT_LOCATION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param location_type:
            The value to assign to the location_type property of this ObjectListInlineInputLocation.
            Allowed values for this property are: "OBJECT_LIST_INLINE_INPUT_LOCATION", "OBJECT_LIST_FILE_INPUT_LOCATION"
        :type location_type: str

        :param object_locations:
            The value to assign to the object_locations property of this ObjectListInlineInputLocation.
        :type object_locations: list[oci.ai_speech.models.ObjectLocation]

        """
        self.swagger_types = {
            'location_type': 'str',
            'object_locations': 'list[ObjectLocation]'
        }

        self.attribute_map = {
            'location_type': 'locationType',
            'object_locations': 'objectLocations'
        }

        self._location_type = None
        self._object_locations = None
        self._location_type = 'OBJECT_LIST_INLINE_INPUT_LOCATION'

    @property
    def object_locations(self):
        """
        **[Required]** Gets the object_locations of this ObjectListInlineInputLocation.
        A list of ObjectLocations.


        :return: The object_locations of this ObjectListInlineInputLocation.
        :rtype: list[oci.ai_speech.models.ObjectLocation]
        """
        return self._object_locations

    @object_locations.setter
    def object_locations(self, object_locations):
        """
        Sets the object_locations of this ObjectListInlineInputLocation.
        A list of ObjectLocations.


        :param object_locations: The object_locations of this ObjectListInlineInputLocation.
        :type: list[oci.ai_speech.models.ObjectLocation]
        """
        self._object_locations = object_locations

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AuthToken(object):
    """
    An `AuthToken` is an Oracle-generated token string that you can use to authenticate with third-party APIs
    that do not support Oracle Cloud Infrastructure's signature-based authentication. For example, use an `AuthToken`
    to authenticate with a Swift client with the Object Storage Service.

    The auth token is associated with the user's Console login. Auth tokens never expire. A user can have up to two
    auth tokens at a time.

    **Note:** The token is always an Oracle-generated string; you can't change it to a string of your choice.

    For more information, see `Managing User Credentials`__.

    __ https://docs.cloud.oracle.com/Content/Identity/access/managing-user-credentials.htm
    """

    #: A constant which can be used with the lifecycle_state property of a AuthToken.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a AuthToken.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a AuthToken.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a AuthToken.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a AuthToken.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new AuthToken object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param token:
            The value to assign to the token property of this AuthToken.
        :type token: str

        :param id:
            The value to assign to the id property of this AuthToken.
        :type id: str

        :param user_id:
            The value to assign to the user_id property of this AuthToken.
        :type user_id: str

        :param description:
            The value to assign to the description property of this AuthToken.
        :type description: str

        :param time_created:
            The value to assign to the time_created property of this AuthToken.
        :type time_created: datetime

        :param time_expires:
            The value to assign to the time_expires property of this AuthToken.
        :type time_expires: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this AuthToken.
            Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param inactive_status:
            The value to assign to the inactive_status property of this AuthToken.
        :type inactive_status: int

        """
        self.swagger_types = {
            'token': 'str',
            'id': 'str',
            'user_id': 'str',
            'description': 'str',
            'time_created': 'datetime',
            'time_expires': 'datetime',
            'lifecycle_state': 'str',
            'inactive_status': 'int'
        }

        self.attribute_map = {
            'token': 'token',
            'id': 'id',
            'user_id': 'userId',
            'description': 'description',
            'time_created': 'timeCreated',
            'time_expires': 'timeExpires',
            'lifecycle_state': 'lifecycleState',
            'inactive_status': 'inactiveStatus'
        }

        self._token = None
        self._id = None
        self._user_id = None
        self._description = None
        self._time_created = None
        self._time_expires = None
        self._lifecycle_state = None
        self._inactive_status = None

    @property
    def token(self):
        """
        Gets the token of this AuthToken.
        The auth token. The value is available only in the response for `CreateAuthToken`, and not
        for `ListAuthTokens` or `UpdateAuthToken`.


        :return: The token of this AuthToken.
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """
        Sets the token of this AuthToken.
        The auth token. The value is available only in the response for `CreateAuthToken`, and not
        for `ListAuthTokens` or `UpdateAuthToken`.


        :param token: The token of this AuthToken.
        :type: str
        """
        self._token = token

    @property
    def id(self):
        """
        Gets the id of this AuthToken.
        The OCID of the auth token.


        :return: The id of this AuthToken.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AuthToken.
        The OCID of the auth token.


        :param id: The id of this AuthToken.
        :type: str
        """
        self._id = id

    @property
    def user_id(self):
        """
        Gets the user_id of this AuthToken.
        The OCID of the user the auth token belongs to.


        :return: The user_id of this AuthToken.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this AuthToken.
        The OCID of the user the auth token belongs to.


        :param user_id: The user_id of this AuthToken.
        :type: str
        """
        self._user_id = user_id

    @property
    def description(self):
        """
        Gets the description of this AuthToken.
        The description you assign to the auth token. Does not have to be unique, and it's changeable.

        (For tenancies that support identity domains) You can have an empty description.


        :return: The description of this AuthToken.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this AuthToken.
        The description you assign to the auth token. Does not have to be unique, and it's changeable.

        (For tenancies that support identity domains) You can have an empty description.


        :param description: The description of this AuthToken.
        :type: str
        """
        self._description = description

    @property
    def time_created(self):
        """
        Gets the time_created of this AuthToken.
        Date and time the `AuthToken` object was created, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :return: The time_created of this AuthToken.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this AuthToken.
        Date and time the `AuthToken` object was created, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :param time_created: The time_created of this AuthToken.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_expires(self):
        """
        Gets the time_expires of this AuthToken.
        Date and time when this auth token will expire, in the format defined by RFC3339.
        Null if it never expires.

        Example: `2016-08-25T21:10:29.600Z`


        :return: The time_expires of this AuthToken.
        :rtype: datetime
        """
        return self._time_expires

    @time_expires.setter
    def time_expires(self, time_expires):
        """
        Sets the time_expires of this AuthToken.
        Date and time when this auth token will expire, in the format defined by RFC3339.
        Null if it never expires.

        Example: `2016-08-25T21:10:29.600Z`


        :param time_expires: The time_expires of this AuthToken.
        :type: datetime
        """
        self._time_expires = time_expires

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this AuthToken.
        The token's current state. After creating an auth token, make sure its `lifecycleState` changes from
        CREATING to ACTIVE before using it.

        Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this AuthToken.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this AuthToken.
        The token's current state. After creating an auth token, make sure its `lifecycleState` changes from
        CREATING to ACTIVE before using it.


        :param lifecycle_state: The lifecycle_state of this AuthToken.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def inactive_status(self):
        """
        Gets the inactive_status of this AuthToken.
        The detailed status of INACTIVE lifecycleState.


        :return: The inactive_status of this AuthToken.
        :rtype: int
        """
        return self._inactive_status

    @inactive_status.setter
    def inactive_status(self, inactive_status):
        """
        Sets the inactive_status of this AuthToken.
        The detailed status of INACTIVE lifecycleState.


        :param inactive_status: The inactive_status of this AuthToken.
        :type: int
        """
        self._inactive_status = inactive_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CertificateRevocationListDetails(object):
    """
    The details of the certificate revocation list (CRL).
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CertificateRevocationListDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param object_storage_config:
            The value to assign to the object_storage_config property of this CertificateRevocationListDetails.
        :type object_storage_config: oci.certificates_management.models.ObjectStorageBucketConfigDetails

        :param custom_formatted_urls:
            The value to assign to the custom_formatted_urls property of this CertificateRevocationListDetails.
        :type custom_formatted_urls: list[str]

        """
        self.swagger_types = {
            'object_storage_config': 'ObjectStorageBucketConfigDetails',
            'custom_formatted_urls': 'list[str]'
        }

        self.attribute_map = {
            'object_storage_config': 'objectStorageConfig',
            'custom_formatted_urls': 'customFormattedUrls'
        }

        self._object_storage_config = None
        self._custom_formatted_urls = None

    @property
    def object_storage_config(self):
        """
        **[Required]** Gets the object_storage_config of this CertificateRevocationListDetails.

        :return: The object_storage_config of this CertificateRevocationListDetails.
        :rtype: oci.certificates_management.models.ObjectStorageBucketConfigDetails
        """
        return self._object_storage_config

    @object_storage_config.setter
    def object_storage_config(self, object_storage_config):
        """
        Sets the object_storage_config of this CertificateRevocationListDetails.

        :param object_storage_config: The object_storage_config of this CertificateRevocationListDetails.
        :type: oci.certificates_management.models.ObjectStorageBucketConfigDetails
        """
        self._object_storage_config = object_storage_config

    @property
    def custom_formatted_urls(self):
        """
        Gets the custom_formatted_urls of this CertificateRevocationListDetails.
        Optional CRL access points, expressed using a format where the version number of the issuing CA is inserted wherever you include a pair of curly braces. This versioning scheme helps avoid collisions when new CA versions are created. For example, myCrlFileIssuedFromCAVersion{}.crl becomes myCrlFileIssuedFromCAVersion2.crl for CA version 2.


        :return: The custom_formatted_urls of this CertificateRevocationListDetails.
        :rtype: list[str]
        """
        return self._custom_formatted_urls

    @custom_formatted_urls.setter
    def custom_formatted_urls(self, custom_formatted_urls):
        """
        Sets the custom_formatted_urls of this CertificateRevocationListDetails.
        Optional CRL access points, expressed using a format where the version number of the issuing CA is inserted wherever you include a pair of curly braces. This versioning scheme helps avoid collisions when new CA versions are created. For example, myCrlFileIssuedFromCAVersion{}.crl becomes myCrlFileIssuedFromCAVersion2.crl for CA version 2.


        :param custom_formatted_urls: The custom_formatted_urls of this CertificateRevocationListDetails.
        :type: list[str]
        """
        self._custom_formatted_urls = custom_formatted_urls

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Validity(object):
    """
    An object that describes a period of time during which an entity is valid. If this is not provided when you create a certificate, the validity of the issuing CA is used.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Validity object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_of_validity_not_before:
            The value to assign to the time_of_validity_not_before property of this Validity.
        :type time_of_validity_not_before: datetime

        :param time_of_validity_not_after:
            The value to assign to the time_of_validity_not_after property of this Validity.
        :type time_of_validity_not_after: datetime

        """
        self.swagger_types = {
            'time_of_validity_not_before': 'datetime',
            'time_of_validity_not_after': 'datetime'
        }

        self.attribute_map = {
            'time_of_validity_not_before': 'timeOfValidityNotBefore',
            'time_of_validity_not_after': 'timeOfValidityNotAfter'
        }

        self._time_of_validity_not_before = None
        self._time_of_validity_not_after = None

    @property
    def time_of_validity_not_before(self):
        """
        Gets the time_of_validity_not_before of this Validity.
        The date on which the certificate validity period begins, expressed in `RFC 3339`__ timestamp format.
        Example: `2019-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_of_validity_not_before of this Validity.
        :rtype: datetime
        """
        return self._time_of_validity_not_before

    @time_of_validity_not_before.setter
    def time_of_validity_not_before(self, time_of_validity_not_before):
        """
        Sets the time_of_validity_not_before of this Validity.
        The date on which the certificate validity period begins, expressed in `RFC 3339`__ timestamp format.
        Example: `2019-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_of_validity_not_before: The time_of_validity_not_before of this Validity.
        :type: datetime
        """
        self._time_of_validity_not_before = time_of_validity_not_before

    @property
    def time_of_validity_not_after(self):
        """
        **[Required]** Gets the time_of_validity_not_after of this Validity.
        The date on which the certificate validity period ends, expressed in `RFC 3339`__ timestamp format.
        Example: `2019-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_of_validity_not_after of this Validity.
        :rtype: datetime
        """
        return self._time_of_validity_not_after

    @time_of_validity_not_after.setter
    def time_of_validity_not_after(self, time_of_validity_not_after):
        """
        Sets the time_of_validity_not_after of this Validity.
        The date on which the certificate validity period ends, expressed in `RFC 3339`__ timestamp format.
        Example: `2019-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_of_validity_not_after: The time_of_validity_not_after of this Validity.
        :type: datetime
        """
        self._time_of_validity_not_after = time_of_validity_not_after

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ExistingInstallationSiteId(object):
    """
    The essential properties to identity a Java installation site.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ExistingInstallationSiteId object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param managed_instance_id:
            The value to assign to the managed_instance_id property of this ExistingInstallationSiteId.
        :type managed_instance_id: str

        :param installation_key:
            The value to assign to the installation_key property of this ExistingInstallationSiteId.
        :type installation_key: str

        """
        self.swagger_types = {
            'managed_instance_id': 'str',
            'installation_key': 'str'
        }

        self.attribute_map = {
            'managed_instance_id': 'managedInstanceId',
            'installation_key': 'installationKey'
        }

        self._managed_instance_id = None
        self._installation_key = None

    @property
    def managed_instance_id(self):
        """
        **[Required]** Gets the managed_instance_id of this ExistingInstallationSiteId.
        The `OCID`__ of the related managed instance.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The managed_instance_id of this ExistingInstallationSiteId.
        :rtype: str
        """
        return self._managed_instance_id

    @managed_instance_id.setter
    def managed_instance_id(self, managed_instance_id):
        """
        Sets the managed_instance_id of this ExistingInstallationSiteId.
        The `OCID`__ of the related managed instance.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param managed_instance_id: The managed_instance_id of this ExistingInstallationSiteId.
        :type: str
        """
        self._managed_instance_id = managed_instance_id

    @property
    def installation_key(self):
        """
        **[Required]** Gets the installation_key of this ExistingInstallationSiteId.
        The unique identifier for the installation of a Java Runtime at a specific path on a specific operating system.


        :return: The installation_key of this ExistingInstallationSiteId.
        :rtype: str
        """
        return self._installation_key

    @installation_key.setter
    def installation_key(self, installation_key):
        """
        Sets the installation_key of this ExistingInstallationSiteId.
        The unique identifier for the installation of a Java Runtime at a specific path on a specific operating system.


        :param installation_key: The installation_key of this ExistingInstallationSiteId.
        :type: str
        """
        self._installation_key = installation_key

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CommitmentDetail(object):
    """
    Subscribed Service commitment summary
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CommitmentDetail object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this CommitmentDetail.
        :type id: str

        :param time_start:
            The value to assign to the time_start property of this CommitmentDetail.
        :type time_start: datetime

        :param time_end:
            The value to assign to the time_end property of this CommitmentDetail.
        :type time_end: datetime

        :param quantity:
            The value to assign to the quantity property of this CommitmentDetail.
        :type quantity: str

        :param used_amount:
            The value to assign to the used_amount property of this CommitmentDetail.
        :type used_amount: str

        :param available_amount:
            The value to assign to the available_amount property of this CommitmentDetail.
        :type available_amount: str

        :param funded_allocation_value:
            The value to assign to the funded_allocation_value property of this CommitmentDetail.
        :type funded_allocation_value: str

        """
        self.swagger_types = {
            'id': 'str',
            'time_start': 'datetime',
            'time_end': 'datetime',
            'quantity': 'str',
            'used_amount': 'str',
            'available_amount': 'str',
            'funded_allocation_value': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'time_start': 'timeStart',
            'time_end': 'timeEnd',
            'quantity': 'quantity',
            'used_amount': 'usedAmount',
            'available_amount': 'availableAmount',
            'funded_allocation_value': 'fundedAllocationValue'
        }

        self._id = None
        self._time_start = None
        self._time_end = None
        self._quantity = None
        self._used_amount = None
        self._available_amount = None
        self._funded_allocation_value = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this CommitmentDetail.
        SPM internal Commitment ID


        :return: The id of this CommitmentDetail.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CommitmentDetail.
        SPM internal Commitment ID


        :param id: The id of this CommitmentDetail.
        :type: str
        """
        self._id = id

    @property
    def time_start(self):
        """
        Gets the time_start of this CommitmentDetail.
        Commitment start date


        :return: The time_start of this CommitmentDetail.
        :rtype: datetime
        """
        return self._time_start

    @time_start.setter
    def time_start(self, time_start):
        """
        Sets the time_start of this CommitmentDetail.
        Commitment start date


        :param time_start: The time_start of this CommitmentDetail.
        :type: datetime
        """
        self._time_start = time_start

    @property
    def time_end(self):
        """
        Gets the time_end of this CommitmentDetail.
        Commitment end date


        :return: The time_end of this CommitmentDetail.
        :rtype: datetime
        """
        return self._time_end

    @time_end.setter
    def time_end(self, time_end):
        """
        Sets the time_end of this CommitmentDetail.
        Commitment end date


        :param time_end: The time_end of this CommitmentDetail.
        :type: datetime
        """
        self._time_end = time_end

    @property
    def quantity(self):
        """
        Gets the quantity of this CommitmentDetail.
        Commitment quantity


        :return: The quantity of this CommitmentDetail.
        :rtype: str
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """
        Sets the quantity of this CommitmentDetail.
        Commitment quantity


        :param quantity: The quantity of this CommitmentDetail.
        :type: str
        """
        self._quantity = quantity

    @property
    def used_amount(self):
        """
        Gets the used_amount of this CommitmentDetail.
        Commitment used amount


        :return: The used_amount of this CommitmentDetail.
        :rtype: str
        """
        return self._used_amount

    @used_amount.setter
    def used_amount(self, used_amount):
        """
        Sets the used_amount of this CommitmentDetail.
        Commitment used amount


        :param used_amount: The used_amount of this CommitmentDetail.
        :type: str
        """
        self._used_amount = used_amount

    @property
    def available_amount(self):
        """
        Gets the available_amount of this CommitmentDetail.
        Commitment available amount


        :return: The available_amount of this CommitmentDetail.
        :rtype: str
        """
        return self._available_amount

    @available_amount.setter
    def available_amount(self, available_amount):
        """
        Sets the available_amount of this CommitmentDetail.
        Commitment available amount


        :param available_amount: The available_amount of this CommitmentDetail.
        :type: str
        """
        self._available_amount = available_amount

    @property
    def funded_allocation_value(self):
        """
        Gets the funded_allocation_value of this CommitmentDetail.
        Funded Allocation line value
        example: 12000.00


        :return: The funded_allocation_value of this CommitmentDetail.
        :rtype: str
        """
        return self._funded_allocation_value

    @funded_allocation_value.setter
    def funded_allocation_value(self, funded_allocation_value):
        """
        Sets the funded_allocation_value of this CommitmentDetail.
        Funded Allocation line value
        example: 12000.00


        :param funded_allocation_value: The funded_allocation_value of this CommitmentDetail.
        :type: str
        """
        self._funded_allocation_value = funded_allocation_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .change_integration_instance_compartment_details import ChangeIntegrationInstanceCompartmentDetails
from .change_integration_instance_network_endpoint_details import ChangeIntegrationInstanceNetworkEndpointDetails
from .create_custom_endpoint_details import CreateCustomEndpointDetails
from .create_integration_instance_details import CreateIntegrationInstanceDetails
from .custom_endpoint_details import CustomEndpointDetails
from .integration_instance import IntegrationInstance
from .integration_instance_summary import IntegrationInstanceSummary
from .network_endpoint_details import NetworkEndpointDetails
from .public_endpoint_details import PublicEndpointDetails
from .update_custom_endpoint_details import UpdateCustomEndpointDetails
from .update_integration_instance_details import UpdateIntegrationInstanceDetails
from .virtual_cloud_network import VirtualCloudNetwork
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for integration services.
integration_type_mapping = {
    "ChangeIntegrationInstanceCompartmentDetails": ChangeIntegrationInstanceCompartmentDetails,
    "ChangeIntegrationInstanceNetworkEndpointDetails": ChangeIntegrationInstanceNetworkEndpointDetails,
    "CreateCustomEndpointDetails": CreateCustomEndpointDetails,
    "CreateIntegrationInstanceDetails": CreateIntegrationInstanceDetails,
    "CustomEndpointDetails": CustomEndpointDetails,
    "IntegrationInstance": IntegrationInstance,
    "IntegrationInstanceSummary": IntegrationInstanceSummary,
    "NetworkEndpointDetails": NetworkEndpointDetails,
    "PublicEndpointDetails": PublicEndpointDetails,
    "UpdateCustomEndpointDetails": UpdateCustomEndpointDetails,
    "UpdateIntegrationInstanceDetails": UpdateIntegrationInstanceDetails,
    "VirtualCloudNetwork": VirtualCloudNetwork,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FormatsForSensitiveType(object):
    """
    A list of library masking formats compatible with an existing sensitive type.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FormatsForSensitiveType object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param sensitive_type_id:
            The value to assign to the sensitive_type_id property of this FormatsForSensitiveType.
        :type sensitive_type_id: str

        :param masking_formats:
            The value to assign to the masking_formats property of this FormatsForSensitiveType.
        :type masking_formats: list[oci.data_safe.models.FormatSummary]

        """
        self.swagger_types = {
            'sensitive_type_id': 'str',
            'masking_formats': 'list[FormatSummary]'
        }

        self.attribute_map = {
            'sensitive_type_id': 'sensitiveTypeId',
            'masking_formats': 'maskingFormats'
        }

        self._sensitive_type_id = None
        self._masking_formats = None

    @property
    def sensitive_type_id(self):
        """
        **[Required]** Gets the sensitive_type_id of this FormatsForSensitiveType.
        The OCID of the sensitive type.


        :return: The sensitive_type_id of this FormatsForSensitiveType.
        :rtype: str
        """
        return self._sensitive_type_id

    @sensitive_type_id.setter
    def sensitive_type_id(self, sensitive_type_id):
        """
        Sets the sensitive_type_id of this FormatsForSensitiveType.
        The OCID of the sensitive type.


        :param sensitive_type_id: The sensitive_type_id of this FormatsForSensitiveType.
        :type: str
        """
        self._sensitive_type_id = sensitive_type_id

    @property
    def masking_formats(self):
        """
        Gets the masking_formats of this FormatsForSensitiveType.
        An array of the library masking formats compatible with the sensitive type.


        :return: The masking_formats of this FormatsForSensitiveType.
        :rtype: list[oci.data_safe.models.FormatSummary]
        """
        return self._masking_formats

    @masking_formats.setter
    def masking_formats(self, masking_formats):
        """
        Sets the masking_formats of this FormatsForSensitiveType.
        An array of the library masking formats compatible with the sensitive type.


        :param masking_formats: The masking_formats of this FormatsForSensitiveType.
        :type: list[oci.data_safe.models.FormatSummary]
        """
        self._masking_formats = masking_formats

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateAuditTrailDetails(object):
    """
    The details used to  update an audit trail.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateAuditTrailDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this UpdateAuditTrailDetails.
        :type description: str

        :param display_name:
            The value to assign to the display_name property of this UpdateAuditTrailDetails.
        :type display_name: str

        :param is_auto_purge_enabled:
            The value to assign to the is_auto_purge_enabled property of this UpdateAuditTrailDetails.
        :type is_auto_purge_enabled: bool

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateAuditTrailDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateAuditTrailDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'description': 'str',
            'display_name': 'str',
            'is_auto_purge_enabled': 'bool',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'description': 'description',
            'display_name': 'displayName',
            'is_auto_purge_enabled': 'isAutoPurgeEnabled',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._description = None
        self._display_name = None
        self._is_auto_purge_enabled = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def description(self):
        """
        Gets the description of this UpdateAuditTrailDetails.
        The description of the audit trail.


        :return: The description of this UpdateAuditTrailDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateAuditTrailDetails.
        The description of the audit trail.


        :param description: The description of this UpdateAuditTrailDetails.
        :type: str
        """
        self._description = description

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateAuditTrailDetails.
        The display name of the audit trail. The name does not have to be unique, and it's changeable.


        :return: The display_name of this UpdateAuditTrailDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateAuditTrailDetails.
        The display name of the audit trail. The name does not have to be unique, and it's changeable.


        :param display_name: The display_name of this UpdateAuditTrailDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def is_auto_purge_enabled(self):
        """
        Gets the is_auto_purge_enabled of this UpdateAuditTrailDetails.
        Indicates if auto purge is enabled on the target database, which helps delete audit data in the
        target database every seven days so that the database's audit trail does not become too large.


        :return: The is_auto_purge_enabled of this UpdateAuditTrailDetails.
        :rtype: bool
        """
        return self._is_auto_purge_enabled

    @is_auto_purge_enabled.setter
    def is_auto_purge_enabled(self, is_auto_purge_enabled):
        """
        Sets the is_auto_purge_enabled of this UpdateAuditTrailDetails.
        Indicates if auto purge is enabled on the target database, which helps delete audit data in the
        target database every seven days so that the database's audit trail does not become too large.


        :param is_auto_purge_enabled: The is_auto_purge_enabled of this UpdateAuditTrailDetails.
        :type: bool
        """
        self._is_auto_purge_enabled = is_auto_purge_enabled

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateAuditTrailDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateAuditTrailDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateAuditTrailDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateAuditTrailDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateAuditTrailDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateAuditTrailDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateAuditTrailDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateAuditTrailDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateConnectionDetails(object):
    """
    Properties used in connection update operations.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateConnectionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_version:
            The value to assign to the model_version property of this UpdateConnectionDetails.
        :type model_version: str

        :param model_type:
            The value to assign to the model_type property of this UpdateConnectionDetails.
        :type model_type: str

        :param name:
            The value to assign to the name property of this UpdateConnectionDetails.
        :type name: str

        :param description:
            The value to assign to the description property of this UpdateConnectionDetails.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this UpdateConnectionDetails.
        :type object_version: int

        :param object_status:
            The value to assign to the object_status property of this UpdateConnectionDetails.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this UpdateConnectionDetails.
        :type identifier: str

        :param primary_schema:
            The value to assign to the primary_schema property of this UpdateConnectionDetails.
        :type primary_schema: oci.data_connectivity.models.Schema

        :param connection_properties:
            The value to assign to the connection_properties property of this UpdateConnectionDetails.
        :type connection_properties: list[oci.data_connectivity.models.ConnectionProperty]

        :param properties:
            The value to assign to the properties property of this UpdateConnectionDetails.
        :type properties: dict(str, object)

        :param type:
            The value to assign to the type property of this UpdateConnectionDetails.
        :type type: str

        :param is_default:
            The value to assign to the is_default property of this UpdateConnectionDetails.
        :type is_default: bool

        :param metadata:
            The value to assign to the metadata property of this UpdateConnectionDetails.
        :type metadata: oci.data_connectivity.models.ObjectMetadata

        :param registry_metadata:
            The value to assign to the registry_metadata property of this UpdateConnectionDetails.
        :type registry_metadata: oci.data_connectivity.models.RegistryMetadata

        """
        self.swagger_types = {
            'model_version': 'str',
            'model_type': 'str',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'object_status': 'int',
            'identifier': 'str',
            'primary_schema': 'Schema',
            'connection_properties': 'list[ConnectionProperty]',
            'properties': 'dict(str, object)',
            'type': 'str',
            'is_default': 'bool',
            'metadata': 'ObjectMetadata',
            'registry_metadata': 'RegistryMetadata'
        }

        self.attribute_map = {
            'model_version': 'modelVersion',
            'model_type': 'modelType',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'primary_schema': 'primarySchema',
            'connection_properties': 'connectionProperties',
            'properties': 'properties',
            'type': 'type',
            'is_default': 'isDefault',
            'metadata': 'metadata',
            'registry_metadata': 'registryMetadata'
        }

        self._model_version = None
        self._model_type = None
        self._name = None
        self._description = None
        self._object_version = None
        self._object_status = None
        self._identifier = None
        self._primary_schema = None
        self._connection_properties = None
        self._properties = None
        self._type = None
        self._is_default = None
        self._metadata = None
        self._registry_metadata = None

    @property
    def model_version(self):
        """
        Gets the model_version of this UpdateConnectionDetails.
        The model version of an object.


        :return: The model_version of this UpdateConnectionDetails.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this UpdateConnectionDetails.
        The model version of an object.


        :param model_version: The model_version of this UpdateConnectionDetails.
        :type: str
        """
        self._model_version = model_version

    @property
    def model_type(self):
        """
        Gets the model_type of this UpdateConnectionDetails.
        The type of the object.


        :return: The model_type of this UpdateConnectionDetails.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this UpdateConnectionDetails.
        The type of the object.


        :param model_type: The model_type of this UpdateConnectionDetails.
        :type: str
        """
        self._model_type = model_type

    @property
    def name(self):
        """
        Gets the name of this UpdateConnectionDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this UpdateConnectionDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UpdateConnectionDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this UpdateConnectionDetails.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this UpdateConnectionDetails.
        User-defined description for the connection.


        :return: The description of this UpdateConnectionDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateConnectionDetails.
        User-defined description for the connection.


        :param description: The description of this UpdateConnectionDetails.
        :type: str
        """
        self._description = description

    @property
    def object_version(self):
        """
        Gets the object_version of this UpdateConnectionDetails.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this UpdateConnectionDetails.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this UpdateConnectionDetails.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this UpdateConnectionDetails.
        :type: int
        """
        self._object_version = object_version

    @property
    def object_status(self):
        """
        Gets the object_status of this UpdateConnectionDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this UpdateConnectionDetails.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this UpdateConnectionDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this UpdateConnectionDetails.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        Gets the identifier of this UpdateConnectionDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this UpdateConnectionDetails.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this UpdateConnectionDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this UpdateConnectionDetails.
        :type: str
        """
        self._identifier = identifier

    @property
    def primary_schema(self):
        """
        Gets the primary_schema of this UpdateConnectionDetails.

        :return: The primary_schema of this UpdateConnectionDetails.
        :rtype: oci.data_connectivity.models.Schema
        """
        return self._primary_schema

    @primary_schema.setter
    def primary_schema(self, primary_schema):
        """
        Sets the primary_schema of this UpdateConnectionDetails.

        :param primary_schema: The primary_schema of this UpdateConnectionDetails.
        :type: oci.data_connectivity.models.Schema
        """
        self._primary_schema = primary_schema

    @property
    def connection_properties(self):
        """
        Gets the connection_properties of this UpdateConnectionDetails.
        The properties for the connection.


        :return: The connection_properties of this UpdateConnectionDetails.
        :rtype: list[oci.data_connectivity.models.ConnectionProperty]
        """
        return self._connection_properties

    @connection_properties.setter
    def connection_properties(self, connection_properties):
        """
        Sets the connection_properties of this UpdateConnectionDetails.
        The properties for the connection.


        :param connection_properties: The connection_properties of this UpdateConnectionDetails.
        :type: list[oci.data_connectivity.models.ConnectionProperty]
        """
        self._connection_properties = connection_properties

    @property
    def properties(self):
        """
        **[Required]** Gets the properties of this UpdateConnectionDetails.
        All the properties for the connection in a key-value map format.


        :return: The properties of this UpdateConnectionDetails.
        :rtype: dict(str, object)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this UpdateConnectionDetails.
        All the properties for the connection in a key-value map format.


        :param properties: The properties of this UpdateConnectionDetails.
        :type: dict(str, object)
        """
        self._properties = properties

    @property
    def type(self):
        """
        **[Required]** Gets the type of this UpdateConnectionDetails.
        Specific Connection Type


        :return: The type of this UpdateConnectionDetails.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this UpdateConnectionDetails.
        Specific Connection Type


        :param type: The type of this UpdateConnectionDetails.
        :type: str
        """
        self._type = type

    @property
    def is_default(self):
        """
        Gets the is_default of this UpdateConnectionDetails.
        The default property for the connection.


        :return: The is_default of this UpdateConnectionDetails.
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """
        Sets the is_default of this UpdateConnectionDetails.
        The default property for the connection.


        :param is_default: The is_default of this UpdateConnectionDetails.
        :type: bool
        """
        self._is_default = is_default

    @property
    def metadata(self):
        """
        Gets the metadata of this UpdateConnectionDetails.

        :return: The metadata of this UpdateConnectionDetails.
        :rtype: oci.data_connectivity.models.ObjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this UpdateConnectionDetails.

        :param metadata: The metadata of this UpdateConnectionDetails.
        :type: oci.data_connectivity.models.ObjectMetadata
        """
        self._metadata = metadata

    @property
    def registry_metadata(self):
        """
        Gets the registry_metadata of this UpdateConnectionDetails.

        :return: The registry_metadata of this UpdateConnectionDetails.
        :rtype: oci.data_connectivity.models.RegistryMetadata
        """
        return self._registry_metadata

    @registry_metadata.setter
    def registry_metadata(self, registry_metadata):
        """
        Sets the registry_metadata of this UpdateConnectionDetails.

        :param registry_metadata: The registry_metadata of this UpdateConnectionDetails.
        :type: oci.data_connectivity.models.RegistryMetadata
        """
        self._registry_metadata = registry_metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RecommendationCount(object):
    """
    The count of recommendations in a category, grouped by importance.
    """

    #: A constant which can be used with the importance property of a RecommendationCount.
    #: This constant has a value of "CRITICAL"
    IMPORTANCE_CRITICAL = "CRITICAL"

    #: A constant which can be used with the importance property of a RecommendationCount.
    #: This constant has a value of "HIGH"
    IMPORTANCE_HIGH = "HIGH"

    #: A constant which can be used with the importance property of a RecommendationCount.
    #: This constant has a value of "MODERATE"
    IMPORTANCE_MODERATE = "MODERATE"

    #: A constant which can be used with the importance property of a RecommendationCount.
    #: This constant has a value of "LOW"
    IMPORTANCE_LOW = "LOW"

    #: A constant which can be used with the importance property of a RecommendationCount.
    #: This constant has a value of "MINOR"
    IMPORTANCE_MINOR = "MINOR"

    def __init__(self, **kwargs):
        """
        Initializes a new RecommendationCount object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param importance:
            The value to assign to the importance property of this RecommendationCount.
            Allowed values for this property are: "CRITICAL", "HIGH", "MODERATE", "LOW", "MINOR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type importance: str

        :param count:
            The value to assign to the count property of this RecommendationCount.
        :type count: int

        """
        self.swagger_types = {
            'importance': 'str',
            'count': 'int'
        }

        self.attribute_map = {
            'importance': 'importance',
            'count': 'count'
        }

        self._importance = None
        self._count = None

    @property
    def importance(self):
        """
        **[Required]** Gets the importance of this RecommendationCount.
        The level of importance assigned to the recommendation.

        Allowed values for this property are: "CRITICAL", "HIGH", "MODERATE", "LOW", "MINOR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The importance of this RecommendationCount.
        :rtype: str
        """
        return self._importance

    @importance.setter
    def importance(self, importance):
        """
        Sets the importance of this RecommendationCount.
        The level of importance assigned to the recommendation.


        :param importance: The importance of this RecommendationCount.
        :type: str
        """
        allowed_values = ["CRITICAL", "HIGH", "MODERATE", "LOW", "MINOR"]
        if not value_allowed_none_or_none_sentinel(importance, allowed_values):
            importance = 'UNKNOWN_ENUM_VALUE'
        self._importance = importance

    @property
    def count(self):
        """
        **[Required]** Gets the count of this RecommendationCount.
        The count of recommendations.


        :return: The count of this RecommendationCount.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this RecommendationCount.
        The count of recommendations.


        :param count: The count of this RecommendationCount.
        :type: int
        """
        self._count = count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AddWorkerNodesDetails(object):
    """
    The information about added nodes.
    """

    #: A constant which can be used with the node_type property of a AddWorkerNodesDetails.
    #: This constant has a value of "WORKER"
    NODE_TYPE_WORKER = "WORKER"

    #: A constant which can be used with the node_type property of a AddWorkerNodesDetails.
    #: This constant has a value of "COMPUTE_ONLY_WORKER"
    NODE_TYPE_COMPUTE_ONLY_WORKER = "COMPUTE_ONLY_WORKER"

    def __init__(self, **kwargs):
        """
        Initializes a new AddWorkerNodesDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param cluster_admin_password:
            The value to assign to the cluster_admin_password property of this AddWorkerNodesDetails.
        :type cluster_admin_password: str

        :param number_of_worker_nodes:
            The value to assign to the number_of_worker_nodes property of this AddWorkerNodesDetails.
        :type number_of_worker_nodes: int

        :param node_type:
            The value to assign to the node_type property of this AddWorkerNodesDetails.
            Allowed values for this property are: "WORKER", "COMPUTE_ONLY_WORKER"
        :type node_type: str

        :param shape:
            The value to assign to the shape property of this AddWorkerNodesDetails.
        :type shape: str

        :param block_volume_size_in_gbs:
            The value to assign to the block_volume_size_in_gbs property of this AddWorkerNodesDetails.
        :type block_volume_size_in_gbs: int

        :param shape_config:
            The value to assign to the shape_config property of this AddWorkerNodesDetails.
        :type shape_config: oci.bds.models.ShapeConfigDetails

        """
        self.swagger_types = {
            'cluster_admin_password': 'str',
            'number_of_worker_nodes': 'int',
            'node_type': 'str',
            'shape': 'str',
            'block_volume_size_in_gbs': 'int',
            'shape_config': 'ShapeConfigDetails'
        }

        self.attribute_map = {
            'cluster_admin_password': 'clusterAdminPassword',
            'number_of_worker_nodes': 'numberOfWorkerNodes',
            'node_type': 'nodeType',
            'shape': 'shape',
            'block_volume_size_in_gbs': 'blockVolumeSizeInGBs',
            'shape_config': 'shapeConfig'
        }

        self._cluster_admin_password = None
        self._number_of_worker_nodes = None
        self._node_type = None
        self._shape = None
        self._block_volume_size_in_gbs = None
        self._shape_config = None

    @property
    def cluster_admin_password(self):
        """
        **[Required]** Gets the cluster_admin_password of this AddWorkerNodesDetails.
        Base-64 encoded password for the cluster (and Cloudera Manager) admin user.


        :return: The cluster_admin_password of this AddWorkerNodesDetails.
        :rtype: str
        """
        return self._cluster_admin_password

    @cluster_admin_password.setter
    def cluster_admin_password(self, cluster_admin_password):
        """
        Sets the cluster_admin_password of this AddWorkerNodesDetails.
        Base-64 encoded password for the cluster (and Cloudera Manager) admin user.


        :param cluster_admin_password: The cluster_admin_password of this AddWorkerNodesDetails.
        :type: str
        """
        self._cluster_admin_password = cluster_admin_password

    @property
    def number_of_worker_nodes(self):
        """
        **[Required]** Gets the number_of_worker_nodes of this AddWorkerNodesDetails.
        Number of additional worker nodes for the cluster.


        :return: The number_of_worker_nodes of this AddWorkerNodesDetails.
        :rtype: int
        """
        return self._number_of_worker_nodes

    @number_of_worker_nodes.setter
    def number_of_worker_nodes(self, number_of_worker_nodes):
        """
        Sets the number_of_worker_nodes of this AddWorkerNodesDetails.
        Number of additional worker nodes for the cluster.


        :param number_of_worker_nodes: The number_of_worker_nodes of this AddWorkerNodesDetails.
        :type: int
        """
        self._number_of_worker_nodes = number_of_worker_nodes

    @property
    def node_type(self):
        """
        **[Required]** Gets the node_type of this AddWorkerNodesDetails.
        Worker node types, can either be Worker Data node or Compute only worker node.

        Allowed values for this property are: "WORKER", "COMPUTE_ONLY_WORKER"


        :return: The node_type of this AddWorkerNodesDetails.
        :rtype: str
        """
        return self._node_type

    @node_type.setter
    def node_type(self, node_type):
        """
        Sets the node_type of this AddWorkerNodesDetails.
        Worker node types, can either be Worker Data node or Compute only worker node.


        :param node_type: The node_type of this AddWorkerNodesDetails.
        :type: str
        """
        allowed_values = ["WORKER", "COMPUTE_ONLY_WORKER"]
        if not value_allowed_none_or_none_sentinel(node_type, allowed_values):
            raise ValueError(
                "Invalid value for `node_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._node_type = node_type

    @property
    def shape(self):
        """
        Gets the shape of this AddWorkerNodesDetails.
        Shape of the node. This has to be specified when adding compute only worker node at the first time. Otherwise, it's a read-only property.


        :return: The shape of this AddWorkerNodesDetails.
        :rtype: str
        """
        return self._shape

    @shape.setter
    def shape(self, shape):
        """
        Sets the shape of this AddWorkerNodesDetails.
        Shape of the node. This has to be specified when adding compute only worker node at the first time. Otherwise, it's a read-only property.


        :param shape: The shape of this AddWorkerNodesDetails.
        :type: str
        """
        self._shape = shape

    @property
    def block_volume_size_in_gbs(self):
        """
        Gets the block_volume_size_in_gbs of this AddWorkerNodesDetails.
        The size of block volume in GB to be attached to the given node. This has to be specified when adding compute only worker node at the first time. Otherwise, it's a read-only property.


        :return: The block_volume_size_in_gbs of this AddWorkerNodesDetails.
        :rtype: int
        """
        return self._block_volume_size_in_gbs

    @block_volume_size_in_gbs.setter
    def block_volume_size_in_gbs(self, block_volume_size_in_gbs):
        """
        Sets the block_volume_size_in_gbs of this AddWorkerNodesDetails.
        The size of block volume in GB to be attached to the given node. This has to be specified when adding compute only worker node at the first time. Otherwise, it's a read-only property.


        :param block_volume_size_in_gbs: The block_volume_size_in_gbs of this AddWorkerNodesDetails.
        :type: int
        """
        self._block_volume_size_in_gbs = block_volume_size_in_gbs

    @property
    def shape_config(self):
        """
        Gets the shape_config of this AddWorkerNodesDetails.

        :return: The shape_config of this AddWorkerNodesDetails.
        :rtype: oci.bds.models.ShapeConfigDetails
        """
        return self._shape_config

    @shape_config.setter
    def shape_config(self, shape_config):
        """
        Sets the shape_config of this AddWorkerNodesDetails.

        :param shape_config: The shape_config of this AddWorkerNodesDetails.
        :type: oci.bds.models.ShapeConfigDetails
        """
        self._shape_config = shape_config

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AutonomousDbVersionSummary(object):
    """
    The supported Autonomous Database version.
    """

    #: A constant which can be used with the db_workload property of a AutonomousDbVersionSummary.
    #: This constant has a value of "OLTP"
    DB_WORKLOAD_OLTP = "OLTP"

    #: A constant which can be used with the db_workload property of a AutonomousDbVersionSummary.
    #: This constant has a value of "DW"
    DB_WORKLOAD_DW = "DW"

    #: A constant which can be used with the db_workload property of a AutonomousDbVersionSummary.
    #: This constant has a value of "AJD"
    DB_WORKLOAD_AJD = "AJD"

    #: A constant which can be used with the db_workload property of a AutonomousDbVersionSummary.
    #: This constant has a value of "APEX"
    DB_WORKLOAD_APEX = "APEX"

    def __init__(self, **kwargs):
        """
        Initializes a new AutonomousDbVersionSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param version:
            The value to assign to the version property of this AutonomousDbVersionSummary.
        :type version: str

        :param db_workload:
            The value to assign to the db_workload property of this AutonomousDbVersionSummary.
            Allowed values for this property are: "OLTP", "DW", "AJD", "APEX", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type db_workload: str

        :param is_dedicated:
            The value to assign to the is_dedicated property of this AutonomousDbVersionSummary.
        :type is_dedicated: bool

        :param details:
            The value to assign to the details property of this AutonomousDbVersionSummary.
        :type details: str

        :param is_free_tier_enabled:
            The value to assign to the is_free_tier_enabled property of this AutonomousDbVersionSummary.
        :type is_free_tier_enabled: bool

        :param is_paid_enabled:
            The value to assign to the is_paid_enabled property of this AutonomousDbVersionSummary.
        :type is_paid_enabled: bool

        :param is_default_for_free:
            The value to assign to the is_default_for_free property of this AutonomousDbVersionSummary.
        :type is_default_for_free: bool

        :param is_default_for_paid:
            The value to assign to the is_default_for_paid property of this AutonomousDbVersionSummary.
        :type is_default_for_paid: bool

        """
        self.swagger_types = {
            'version': 'str',
            'db_workload': 'str',
            'is_dedicated': 'bool',
            'details': 'str',
            'is_free_tier_enabled': 'bool',
            'is_paid_enabled': 'bool',
            'is_default_for_free': 'bool',
            'is_default_for_paid': 'bool'
        }

        self.attribute_map = {
            'version': 'version',
            'db_workload': 'dbWorkload',
            'is_dedicated': 'isDedicated',
            'details': 'details',
            'is_free_tier_enabled': 'isFreeTierEnabled',
            'is_paid_enabled': 'isPaidEnabled',
            'is_default_for_free': 'isDefaultForFree',
            'is_default_for_paid': 'isDefaultForPaid'
        }

        self._version = None
        self._db_workload = None
        self._is_dedicated = None
        self._details = None
        self._is_free_tier_enabled = None
        self._is_paid_enabled = None
        self._is_default_for_free = None
        self._is_default_for_paid = None

    @property
    def version(self):
        """
        **[Required]** Gets the version of this AutonomousDbVersionSummary.
        A valid Oracle Database version for Autonomous Database.


        :return: The version of this AutonomousDbVersionSummary.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this AutonomousDbVersionSummary.
        A valid Oracle Database version for Autonomous Database.


        :param version: The version of this AutonomousDbVersionSummary.
        :type: str
        """
        self._version = version

    @property
    def db_workload(self):
        """
        Gets the db_workload of this AutonomousDbVersionSummary.
        The Autonomous Database workload type. The following values are valid:

        - OLTP - indicates an Autonomous Transaction Processing database
        - DW - indicates an Autonomous Data Warehouse database
        - AJD - indicates an Autonomous JSON Database
        - APEX - indicates an Autonomous Database with the Oracle APEX Application Development workload type.

        Allowed values for this property are: "OLTP", "DW", "AJD", "APEX", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The db_workload of this AutonomousDbVersionSummary.
        :rtype: str
        """
        return self._db_workload

    @db_workload.setter
    def db_workload(self, db_workload):
        """
        Sets the db_workload of this AutonomousDbVersionSummary.
        The Autonomous Database workload type. The following values are valid:

        - OLTP - indicates an Autonomous Transaction Processing database
        - DW - indicates an Autonomous Data Warehouse database
        - AJD - indicates an Autonomous JSON Database
        - APEX - indicates an Autonomous Database with the Oracle APEX Application Development workload type.


        :param db_workload: The db_workload of this AutonomousDbVersionSummary.
        :type: str
        """
        allowed_values = ["OLTP", "DW", "AJD", "APEX"]
        if not value_allowed_none_or_none_sentinel(db_workload, allowed_values):
            db_workload = 'UNKNOWN_ENUM_VALUE'
        self._db_workload = db_workload

    @property
    def is_dedicated(self):
        """
        Gets the is_dedicated of this AutonomousDbVersionSummary.
        True if the database uses `dedicated Exadata infrastructure`__.

        __ https://docs.oracle.com/en/cloud/paas/autonomous-database/index.html


        :return: The is_dedicated of this AutonomousDbVersionSummary.
        :rtype: bool
        """
        return self._is_dedicated

    @is_dedicated.setter
    def is_dedicated(self, is_dedicated):
        """
        Sets the is_dedicated of this AutonomousDbVersionSummary.
        True if the database uses `dedicated Exadata infrastructure`__.

        __ https://docs.oracle.com/en/cloud/paas/autonomous-database/index.html


        :param is_dedicated: The is_dedicated of this AutonomousDbVersionSummary.
        :type: bool
        """
        self._is_dedicated = is_dedicated

    @property
    def details(self):
        """
        Gets the details of this AutonomousDbVersionSummary.
        A URL that points to a detailed description of the Autonomous Database version.


        :return: The details of this AutonomousDbVersionSummary.
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """
        Sets the details of this AutonomousDbVersionSummary.
        A URL that points to a detailed description of the Autonomous Database version.


        :param details: The details of this AutonomousDbVersionSummary.
        :type: str
        """
        self._details = details

    @property
    def is_free_tier_enabled(self):
        """
        Gets the is_free_tier_enabled of this AutonomousDbVersionSummary.
        True if this version of the Oracle Database software can be used for Always-Free Autonomous Databases.


        :return: The is_free_tier_enabled of this AutonomousDbVersionSummary.
        :rtype: bool
        """
        return self._is_free_tier_enabled

    @is_free_tier_enabled.setter
    def is_free_tier_enabled(self, is_free_tier_enabled):
        """
        Sets the is_free_tier_enabled of this AutonomousDbVersionSummary.
        True if this version of the Oracle Database software can be used for Always-Free Autonomous Databases.


        :param is_free_tier_enabled: The is_free_tier_enabled of this AutonomousDbVersionSummary.
        :type: bool
        """
        self._is_free_tier_enabled = is_free_tier_enabled

    @property
    def is_paid_enabled(self):
        """
        Gets the is_paid_enabled of this AutonomousDbVersionSummary.
        True if this version of the Oracle Database software has payments enabled.


        :return: The is_paid_enabled of this AutonomousDbVersionSummary.
        :rtype: bool
        """
        return self._is_paid_enabled

    @is_paid_enabled.setter
    def is_paid_enabled(self, is_paid_enabled):
        """
        Sets the is_paid_enabled of this AutonomousDbVersionSummary.
        True if this version of the Oracle Database software has payments enabled.


        :param is_paid_enabled: The is_paid_enabled of this AutonomousDbVersionSummary.
        :type: bool
        """
        self._is_paid_enabled = is_paid_enabled

    @property
    def is_default_for_free(self):
        """
        Gets the is_default_for_free of this AutonomousDbVersionSummary.
        True if this version of the Oracle Database software's default is free.


        :return: The is_default_for_free of this AutonomousDbVersionSummary.
        :rtype: bool
        """
        return self._is_default_for_free

    @is_default_for_free.setter
    def is_default_for_free(self, is_default_for_free):
        """
        Sets the is_default_for_free of this AutonomousDbVersionSummary.
        True if this version of the Oracle Database software's default is free.


        :param is_default_for_free: The is_default_for_free of this AutonomousDbVersionSummary.
        :type: bool
        """
        self._is_default_for_free = is_default_for_free

    @property
    def is_default_for_paid(self):
        """
        Gets the is_default_for_paid of this AutonomousDbVersionSummary.
        True if this version of the Oracle Database software's default is paid.


        :return: The is_default_for_paid of this AutonomousDbVersionSummary.
        :rtype: bool
        """
        return self._is_default_for_paid

    @is_default_for_paid.setter
    def is_default_for_paid(self, is_default_for_paid):
        """
        Sets the is_default_for_paid of this AutonomousDbVersionSummary.
        True if this version of the Oracle Database software's default is paid.


        :param is_default_for_paid: The is_default_for_paid of this AutonomousDbVersionSummary.
        :type: bool
        """
        self._is_default_for_paid = is_default_for_paid

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .source_details import SourceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ObjectStorageSourceDetails(SourceDetails):
    """
    Object Storage Source Details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ObjectStorageSourceDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.data_labeling_service_dataplane.models.ObjectStorageSourceDetails.source_type` attribute
        of this class is ``OBJECT_STORAGE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source_type:
            The value to assign to the source_type property of this ObjectStorageSourceDetails.
            Allowed values for this property are: "OBJECT_STORAGE"
        :type source_type: str

        :param relative_path:
            The value to assign to the relative_path property of this ObjectStorageSourceDetails.
        :type relative_path: str

        :param path:
            The value to assign to the path property of this ObjectStorageSourceDetails.
        :type path: str

        :param offset:
            The value to assign to the offset property of this ObjectStorageSourceDetails.
        :type offset: float

        :param length:
            The value to assign to the length property of this ObjectStorageSourceDetails.
        :type length: float

        """
        self.swagger_types = {
            'source_type': 'str',
            'relative_path': 'str',
            'path': 'str',
            'offset': 'float',
            'length': 'float'
        }

        self.attribute_map = {
            'source_type': 'sourceType',
            'relative_path': 'relativePath',
            'path': 'path',
            'offset': 'offset',
            'length': 'length'
        }

        self._source_type = None
        self._relative_path = None
        self._path = None
        self._offset = None
        self._length = None
        self._source_type = 'OBJECT_STORAGE'

    @property
    def relative_path(self):
        """
        **[Required]** Gets the relative_path of this ObjectStorageSourceDetails.
        The path relative to the prefix specified in the dataset source details (file name).


        :return: The relative_path of this ObjectStorageSourceDetails.
        :rtype: str
        """
        return self._relative_path

    @relative_path.setter
    def relative_path(self, relative_path):
        """
        Sets the relative_path of this ObjectStorageSourceDetails.
        The path relative to the prefix specified in the dataset source details (file name).


        :param relative_path: The relative_path of this ObjectStorageSourceDetails.
        :type: str
        """
        self._relative_path = relative_path

    @property
    def path(self):
        """
        **[Required]** Gets the path of this ObjectStorageSourceDetails.
        The full path of the file this record belongs to.


        :return: The path of this ObjectStorageSourceDetails.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this ObjectStorageSourceDetails.
        The full path of the file this record belongs to.


        :param path: The path of this ObjectStorageSourceDetails.
        :type: str
        """
        self._path = path

    @property
    def offset(self):
        """
        Gets the offset of this ObjectStorageSourceDetails.
        The offset into the file containing the content.


        :return: The offset of this ObjectStorageSourceDetails.
        :rtype: float
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """
        Sets the offset of this ObjectStorageSourceDetails.
        The offset into the file containing the content.


        :param offset: The offset of this ObjectStorageSourceDetails.
        :type: float
        """
        self._offset = offset

    @property
    def length(self):
        """
        Gets the length of this ObjectStorageSourceDetails.
        The length from the offset into the file containing the content.


        :return: The length of this ObjectStorageSourceDetails.
        :rtype: float
        """
        return self._length

    @length.setter
    def length(self, length):
        """
        Sets the length of this ObjectStorageSourceDetails.
        The length from the offset into the file containing the content.


        :param length: The length of this ObjectStorageSourceDetails.
        :type: float
        """
        self._length = length

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RepositoryCommit(object):
    """
    Commit object with commit information.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RepositoryCommit object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param commit_id:
            The value to assign to the commit_id property of this RepositoryCommit.
        :type commit_id: str

        :param commit_message:
            The value to assign to the commit_message property of this RepositoryCommit.
        :type commit_message: str

        :param author_name:
            The value to assign to the author_name property of this RepositoryCommit.
        :type author_name: str

        :param author_email:
            The value to assign to the author_email property of this RepositoryCommit.
        :type author_email: str

        :param committer_name:
            The value to assign to the committer_name property of this RepositoryCommit.
        :type committer_name: str

        :param committer_email:
            The value to assign to the committer_email property of this RepositoryCommit.
        :type committer_email: str

        :param parent_commit_ids:
            The value to assign to the parent_commit_ids property of this RepositoryCommit.
        :type parent_commit_ids: list[str]

        :param time_created:
            The value to assign to the time_created property of this RepositoryCommit.
        :type time_created: datetime

        :param tree_id:
            The value to assign to the tree_id property of this RepositoryCommit.
        :type tree_id: str

        """
        self.swagger_types = {
            'commit_id': 'str',
            'commit_message': 'str',
            'author_name': 'str',
            'author_email': 'str',
            'committer_name': 'str',
            'committer_email': 'str',
            'parent_commit_ids': 'list[str]',
            'time_created': 'datetime',
            'tree_id': 'str'
        }

        self.attribute_map = {
            'commit_id': 'commitId',
            'commit_message': 'commitMessage',
            'author_name': 'authorName',
            'author_email': 'authorEmail',
            'committer_name': 'committerName',
            'committer_email': 'committerEmail',
            'parent_commit_ids': 'parentCommitIds',
            'time_created': 'timeCreated',
            'tree_id': 'treeId'
        }

        self._commit_id = None
        self._commit_message = None
        self._author_name = None
        self._author_email = None
        self._committer_name = None
        self._committer_email = None
        self._parent_commit_ids = None
        self._time_created = None
        self._tree_id = None

    @property
    def commit_id(self):
        """
        **[Required]** Gets the commit_id of this RepositoryCommit.
        Commit hash pointed to by reference name.


        :return: The commit_id of this RepositoryCommit.
        :rtype: str
        """
        return self._commit_id

    @commit_id.setter
    def commit_id(self, commit_id):
        """
        Sets the commit_id of this RepositoryCommit.
        Commit hash pointed to by reference name.


        :param commit_id: The commit_id of this RepositoryCommit.
        :type: str
        """
        self._commit_id = commit_id

    @property
    def commit_message(self):
        """
        **[Required]** Gets the commit_message of this RepositoryCommit.
        The commit message.


        :return: The commit_message of this RepositoryCommit.
        :rtype: str
        """
        return self._commit_message

    @commit_message.setter
    def commit_message(self, commit_message):
        """
        Sets the commit_message of this RepositoryCommit.
        The commit message.


        :param commit_message: The commit_message of this RepositoryCommit.
        :type: str
        """
        self._commit_message = commit_message

    @property
    def author_name(self):
        """
        Gets the author_name of this RepositoryCommit.
        Name of the author of the repository.


        :return: The author_name of this RepositoryCommit.
        :rtype: str
        """
        return self._author_name

    @author_name.setter
    def author_name(self, author_name):
        """
        Sets the author_name of this RepositoryCommit.
        Name of the author of the repository.


        :param author_name: The author_name of this RepositoryCommit.
        :type: str
        """
        self._author_name = author_name

    @property
    def author_email(self):
        """
        Gets the author_email of this RepositoryCommit.
        Email of the author of the repository.


        :return: The author_email of this RepositoryCommit.
        :rtype: str
        """
        return self._author_email

    @author_email.setter
    def author_email(self, author_email):
        """
        Sets the author_email of this RepositoryCommit.
        Email of the author of the repository.


        :param author_email: The author_email of this RepositoryCommit.
        :type: str
        """
        self._author_email = author_email

    @property
    def committer_name(self):
        """
        Gets the committer_name of this RepositoryCommit.
        Name of who creates the commit.


        :return: The committer_name of this RepositoryCommit.
        :rtype: str
        """
        return self._committer_name

    @committer_name.setter
    def committer_name(self, committer_name):
        """
        Sets the committer_name of this RepositoryCommit.
        Name of who creates the commit.


        :param committer_name: The committer_name of this RepositoryCommit.
        :type: str
        """
        self._committer_name = committer_name

    @property
    def committer_email(self):
        """
        Gets the committer_email of this RepositoryCommit.
        Email of who creates the commit.


        :return: The committer_email of this RepositoryCommit.
        :rtype: str
        """
        return self._committer_email

    @committer_email.setter
    def committer_email(self, committer_email):
        """
        Sets the committer_email of this RepositoryCommit.
        Email of who creates the commit.


        :param committer_email: The committer_email of this RepositoryCommit.
        :type: str
        """
        self._committer_email = committer_email

    @property
    def parent_commit_ids(self):
        """
        Gets the parent_commit_ids of this RepositoryCommit.
        An array of parent commit IDs of created commit.


        :return: The parent_commit_ids of this RepositoryCommit.
        :rtype: list[str]
        """
        return self._parent_commit_ids

    @parent_commit_ids.setter
    def parent_commit_ids(self, parent_commit_ids):
        """
        Sets the parent_commit_ids of this RepositoryCommit.
        An array of parent commit IDs of created commit.


        :param parent_commit_ids: The parent_commit_ids of this RepositoryCommit.
        :type: list[str]
        """
        self._parent_commit_ids = parent_commit_ids

    @property
    def time_created(self):
        """
        Gets the time_created of this RepositoryCommit.
        The time at which commit was created.


        :return: The time_created of this RepositoryCommit.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this RepositoryCommit.
        The time at which commit was created.


        :param time_created: The time_created of this RepositoryCommit.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def tree_id(self):
        """
        Gets the tree_id of this RepositoryCommit.
        Tree information for the specified commit.


        :return: The tree_id of this RepositoryCommit.
        :rtype: str
        """
        return self._tree_id

    @tree_id.setter
    def tree_id(self, tree_id):
        """
        Sets the tree_id of this RepositoryCommit.
        Tree information for the specified commit.


        :param tree_id: The tree_id of this RepositoryCommit.
        :type: str
        """
        self._tree_id = tree_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateLicenseRecordDetails(object):
    """
    The details about updates in the license record.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateLicenseRecordDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateLicenseRecordDetails.
        :type display_name: str

        :param is_perpetual:
            The value to assign to the is_perpetual property of this UpdateLicenseRecordDetails.
        :type is_perpetual: bool

        :param expiration_date:
            The value to assign to the expiration_date property of this UpdateLicenseRecordDetails.
        :type expiration_date: datetime

        :param support_end_date:
            The value to assign to the support_end_date property of this UpdateLicenseRecordDetails.
        :type support_end_date: datetime

        :param is_unlimited:
            The value to assign to the is_unlimited property of this UpdateLicenseRecordDetails.
        :type is_unlimited: bool

        :param license_count:
            The value to assign to the license_count property of this UpdateLicenseRecordDetails.
        :type license_count: int

        :param product_id:
            The value to assign to the product_id property of this UpdateLicenseRecordDetails.
        :type product_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateLicenseRecordDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateLicenseRecordDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'is_perpetual': 'bool',
            'expiration_date': 'datetime',
            'support_end_date': 'datetime',
            'is_unlimited': 'bool',
            'license_count': 'int',
            'product_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'is_perpetual': 'isPerpetual',
            'expiration_date': 'expirationDate',
            'support_end_date': 'supportEndDate',
            'is_unlimited': 'isUnlimited',
            'license_count': 'licenseCount',
            'product_id': 'productId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._is_perpetual = None
        self._expiration_date = None
        self._support_end_date = None
        self._is_unlimited = None
        self._license_count = None
        self._product_id = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this UpdateLicenseRecordDetails.
        License record name.


        :return: The display_name of this UpdateLicenseRecordDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateLicenseRecordDetails.
        License record name.


        :param display_name: The display_name of this UpdateLicenseRecordDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def is_perpetual(self):
        """
        **[Required]** Gets the is_perpetual of this UpdateLicenseRecordDetails.
        Specifies if the license record term is perpertual.


        :return: The is_perpetual of this UpdateLicenseRecordDetails.
        :rtype: bool
        """
        return self._is_perpetual

    @is_perpetual.setter
    def is_perpetual(self, is_perpetual):
        """
        Sets the is_perpetual of this UpdateLicenseRecordDetails.
        Specifies if the license record term is perpertual.


        :param is_perpetual: The is_perpetual of this UpdateLicenseRecordDetails.
        :type: bool
        """
        self._is_perpetual = is_perpetual

    @property
    def expiration_date(self):
        """
        Gets the expiration_date of this UpdateLicenseRecordDetails.
        The license record end date in `RFC 3339`__
        date format.
        Example: `2018-09-12`

        __ https://tools.ietf.org/html/rfc3339


        :return: The expiration_date of this UpdateLicenseRecordDetails.
        :rtype: datetime
        """
        return self._expiration_date

    @expiration_date.setter
    def expiration_date(self, expiration_date):
        """
        Sets the expiration_date of this UpdateLicenseRecordDetails.
        The license record end date in `RFC 3339`__
        date format.
        Example: `2018-09-12`

        __ https://tools.ietf.org/html/rfc3339


        :param expiration_date: The expiration_date of this UpdateLicenseRecordDetails.
        :type: datetime
        """
        self._expiration_date = expiration_date

    @property
    def support_end_date(self):
        """
        Gets the support_end_date of this UpdateLicenseRecordDetails.
        The license record support end date in `RFC 3339`__
        date format.
        Example: `2018-09-12`

        __ https://tools.ietf.org/html/rfc3339


        :return: The support_end_date of this UpdateLicenseRecordDetails.
        :rtype: datetime
        """
        return self._support_end_date

    @support_end_date.setter
    def support_end_date(self, support_end_date):
        """
        Sets the support_end_date of this UpdateLicenseRecordDetails.
        The license record support end date in `RFC 3339`__
        date format.
        Example: `2018-09-12`

        __ https://tools.ietf.org/html/rfc3339


        :param support_end_date: The support_end_date of this UpdateLicenseRecordDetails.
        :type: datetime
        """
        self._support_end_date = support_end_date

    @property
    def is_unlimited(self):
        """
        **[Required]** Gets the is_unlimited of this UpdateLicenseRecordDetails.
        Specifies if the license count is unlimited.


        :return: The is_unlimited of this UpdateLicenseRecordDetails.
        :rtype: bool
        """
        return self._is_unlimited

    @is_unlimited.setter
    def is_unlimited(self, is_unlimited):
        """
        Sets the is_unlimited of this UpdateLicenseRecordDetails.
        Specifies if the license count is unlimited.


        :param is_unlimited: The is_unlimited of this UpdateLicenseRecordDetails.
        :type: bool
        """
        self._is_unlimited = is_unlimited

    @property
    def license_count(self):
        """
        Gets the license_count of this UpdateLicenseRecordDetails.
        The number of license units added by a user in a license record.
        Default 1


        :return: The license_count of this UpdateLicenseRecordDetails.
        :rtype: int
        """
        return self._license_count

    @license_count.setter
    def license_count(self, license_count):
        """
        Sets the license_count of this UpdateLicenseRecordDetails.
        The number of license units added by a user in a license record.
        Default 1


        :param license_count: The license_count of this UpdateLicenseRecordDetails.
        :type: int
        """
        self._license_count = license_count

    @property
    def product_id(self):
        """
        Gets the product_id of this UpdateLicenseRecordDetails.
        The license record product ID.


        :return: The product_id of this UpdateLicenseRecordDetails.
        :rtype: str
        """
        return self._product_id

    @product_id.setter
    def product_id(self, product_id):
        """
        Sets the product_id of this UpdateLicenseRecordDetails.
        The license record product ID.


        :param product_id: The product_id of this UpdateLicenseRecordDetails.
        :type: str
        """
        self._product_id = product_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateLicenseRecordDetails.
        Simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this UpdateLicenseRecordDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateLicenseRecordDetails.
        Simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this UpdateLicenseRecordDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateLicenseRecordDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this UpdateLicenseRecordDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateLicenseRecordDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this UpdateLicenseRecordDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DimensionDetails(object):
    """
    A dimension name and value.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DimensionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this DimensionDetails.
        :type name: str

        :param dimension_value:
            The value to assign to the dimension_value property of this DimensionDetails.
        :type dimension_value: oci.sch.models.DimensionValueDetails

        """
        self.swagger_types = {
            'name': 'str',
            'dimension_value': 'DimensionValueDetails'
        }

        self.attribute_map = {
            'name': 'name',
            'dimension_value': 'dimensionValue'
        }

        self._name = None
        self._dimension_value = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this DimensionDetails.
        Dimension key. A valid dimension key includes only printable ASCII, excluding periods (.) and spaces.
        Custom dimension keys are acceptable. Avoid entering confidential information.
        Due to use by Service Connector Hub, the following dimension names are reserved: `connectorId`, `connectorName`, `connectorSourceType`.
        For information on valid dimension keys and values, see :func:`metric_data_details`.
        Example: `type`


        :return: The name of this DimensionDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DimensionDetails.
        Dimension key. A valid dimension key includes only printable ASCII, excluding periods (.) and spaces.
        Custom dimension keys are acceptable. Avoid entering confidential information.
        Due to use by Service Connector Hub, the following dimension names are reserved: `connectorId`, `connectorName`, `connectorSourceType`.
        For information on valid dimension keys and values, see :func:`metric_data_details`.
        Example: `type`


        :param name: The name of this DimensionDetails.
        :type: str
        """
        self._name = name

    @property
    def dimension_value(self):
        """
        **[Required]** Gets the dimension_value of this DimensionDetails.

        :return: The dimension_value of this DimensionDetails.
        :rtype: oci.sch.models.DimensionValueDetails
        """
        return self._dimension_value

    @dimension_value.setter
    def dimension_value(self, dimension_value):
        """
        Sets the dimension_value of this DimensionDetails.

        :param dimension_value: The dimension_value of this DimensionDetails.
        :type: oci.sch.models.DimensionValueDetails
        """
        self._dimension_value = dimension_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ChangeRetentionDetails(object):
    """
    Details for the audit retention months to be modified.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ChangeRetentionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param online_months:
            The value to assign to the online_months property of this ChangeRetentionDetails.
        :type online_months: int

        :param offline_months:
            The value to assign to the offline_months property of this ChangeRetentionDetails.
        :type offline_months: int

        :param is_override_global_retention_setting:
            The value to assign to the is_override_global_retention_setting property of this ChangeRetentionDetails.
        :type is_override_global_retention_setting: bool

        """
        self.swagger_types = {
            'online_months': 'int',
            'offline_months': 'int',
            'is_override_global_retention_setting': 'bool'
        }

        self.attribute_map = {
            'online_months': 'onlineMonths',
            'offline_months': 'offlineMonths',
            'is_override_global_retention_setting': 'isOverrideGlobalRetentionSetting'
        }

        self._online_months = None
        self._offline_months = None
        self._is_override_global_retention_setting = None

    @property
    def online_months(self):
        """
        Gets the online_months of this ChangeRetentionDetails.
        Indicates the number of months the audit records will be stored online in Oracle Data Safe audit repository for
        immediate reporting and analysis. Minimum: 1; Maximum:12 months


        :return: The online_months of this ChangeRetentionDetails.
        :rtype: int
        """
        return self._online_months

    @online_months.setter
    def online_months(self, online_months):
        """
        Sets the online_months of this ChangeRetentionDetails.
        Indicates the number of months the audit records will be stored online in Oracle Data Safe audit repository for
        immediate reporting and analysis. Minimum: 1; Maximum:12 months


        :param online_months: The online_months of this ChangeRetentionDetails.
        :type: int
        """
        self._online_months = online_months

    @property
    def offline_months(self):
        """
        Gets the offline_months of this ChangeRetentionDetails.
        Indicates the number of months the audit records will be stored offline in the Data Safe audit archive.
        Minimum: 0; Maximum: 72 months.
        If you have a requirement to store the audit data even longer in archive, please contact the Oracle Support.


        :return: The offline_months of this ChangeRetentionDetails.
        :rtype: int
        """
        return self._offline_months

    @offline_months.setter
    def offline_months(self, offline_months):
        """
        Sets the offline_months of this ChangeRetentionDetails.
        Indicates the number of months the audit records will be stored offline in the Data Safe audit archive.
        Minimum: 0; Maximum: 72 months.
        If you have a requirement to store the audit data even longer in archive, please contact the Oracle Support.


        :param offline_months: The offline_months of this ChangeRetentionDetails.
        :type: int
        """
        self._offline_months = offline_months

    @property
    def is_override_global_retention_setting(self):
        """
        Gets the is_override_global_retention_setting of this ChangeRetentionDetails.
        Indicates whether audit retention settings like online and offline months is set at the
        target level overriding the global audit retention settings.


        :return: The is_override_global_retention_setting of this ChangeRetentionDetails.
        :rtype: bool
        """
        return self._is_override_global_retention_setting

    @is_override_global_retention_setting.setter
    def is_override_global_retention_setting(self, is_override_global_retention_setting):
        """
        Sets the is_override_global_retention_setting of this ChangeRetentionDetails.
        Indicates whether audit retention settings like online and offline months is set at the
        target level overriding the global audit retention settings.


        :param is_override_global_retention_setting: The is_override_global_retention_setting of this ChangeRetentionDetails.
        :type: bool
        """
        self._is_override_global_retention_setting = is_override_global_retention_setting

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
